@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,10 +34,11 @@ import org.openide.util.NbBundle;
  */
 public class MavenApplicationType extends MainClassApplicationType {
     
-    MavenApplicationType(Application app) {
-        super(app, "Apache Maven", NbBundle.getMessage( // NOI18N
-                MainClassApplicationType.class, "DESCR_JDeveloperApplicationType"), // NOI18N
-                "org/graalvm/visualvm/application/type/resources/Maven2Icon.png"); // NOI18N
+    MavenApplicationType(Application app, boolean wrapper) {
+        super(app,
+              wrapper ? "Apache Maven Wrapper" : "Apache Maven",     // NOI18N
+              NbBundle.getMessage(MavenApplicationType.class, wrapper ? "DESCR_MavenWrapperApplicationType" : "DESCR_MavenApplicationType"), // NOI18N
+              "org/graalvm/visualvm/application/type/resources/Maven2Icon.png"); // NOI18N
     }    
     
 }
