@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -35,8 +35,10 @@ import org.graalvm.visualvm.application.jvm.Jvm;
 public class MavenApplicationTypeFactory extends MainClassApplicationTypeFactory {
     
     private static final String MAIN_CLASS = "org.codehaus.classworlds.Launcher"; // NOI18N
+    private static final String MAIN_CLASS_1 = "org.codehaus.plexus.classworlds.launcher.Launcher"; // NOI18N
     private static final String PROP_1 = "-Dclassworlds.conf="; // NOI18N
     private static final String PROP_2 = "-Dmaven.home="; // NOI18N
+    private static final String WRAPPER_MAIN_CLASS = "org.apache.maven.wrapper.MavenWrapperMain";   // NOI18N
     
     /**
      * Detects Apache Maven. It returns
@@ -46,14 +48,17 @@ public class MavenApplicationTypeFactory extends MainClassApplicationTypeFactory
      * this application is not Apache Maven
      */
     public ApplicationType createApplicationTypeFor(Application app, Jvm jvm, String mainClass) {
-        if (MAIN_CLASS.equals(mainClass)) {
+        if (MAIN_CLASS.equals(mainClass) || MAIN_CLASS_1.equals(mainClass)) {
             String args = jvm.getJvmArgs();
             if (args != null) {
                 if (args.contains(PROP_1) && args.contains(PROP_2)) {
-                    return new MavenApplicationType(app);
+                    return new MavenApplicationType(app, false);
                 }
             }
         }
+        if (WRAPPER_MAIN_CLASS.equals(mainClass)) {
+            return new MavenApplicationType(app, true);
+        }
         return null;
     }
     
