@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,22 +25,6 @@
 
 package org.graalvm.visualvm.application.views.monitor;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.application.jvm.Jvm;
-import org.graalvm.visualvm.application.jvm.JvmFactory;
-import org.graalvm.visualvm.application.jvm.MonitoredData;
-import org.graalvm.visualvm.application.jvm.MonitoredDataListener;
-import org.graalvm.visualvm.charts.SimpleXYChartSupport;
-import org.graalvm.visualvm.core.datasource.DataSource;
-import org.graalvm.visualvm.core.datasource.Storage;
-import org.graalvm.visualvm.core.options.GlobalPreferences;
-import org.graalvm.visualvm.core.snapshot.Snapshot;
-import org.graalvm.visualvm.heapdump.HeapDumpSupport;
-import org.graalvm.visualvm.tools.jmx.JmxModel;
-import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
-import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
@@ -53,7 +37,23 @@ import java.util.List;
 import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.graalvm.visualvm.application.Application;
+import org.graalvm.visualvm.application.jvm.Jvm;
+import org.graalvm.visualvm.application.jvm.JvmFactory;
+import org.graalvm.visualvm.application.jvm.MonitoredData;
+import org.graalvm.visualvm.application.jvm.MonitoredDataListener;
+import org.graalvm.visualvm.charts.SimpleXYChartSupport;
 import org.graalvm.visualvm.core.VisualVM;
+import org.graalvm.visualvm.core.datasource.DataSource;
+import org.graalvm.visualvm.core.datasource.Storage;
+import org.graalvm.visualvm.core.options.GlobalPreferences;
+import org.graalvm.visualvm.core.snapshot.Snapshot;
+import org.graalvm.visualvm.heapdump.HeapDumpSupport;
+import org.graalvm.visualvm.tools.jmx.JmxModel;
+import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
+import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import org.openide.util.NbBundle;
 
 
@@ -284,7 +284,6 @@ final class ApplicationMonitorModel {
             jvm.removeMonitoredDataListener(monitoredDataListener);
     }
 
-
     public void addChangeListener(ChangeListener listener) {
         if (live) listeners.add(listener);
     }
@@ -445,25 +444,23 @@ final class ApplicationMonitorModel {
         processorsCount = 1;
         
         jvm = JvmFactory.getJVMFor(application);
-        if (jvm != null) {
-            HeapDumpSupport hds = HeapDumpSupport.getInstance();
-            if (application.isLocalApplication()) {
-                takeHeapDumpSupported = hds.supportsHeapDump(application);
-            } else {
-                takeHeapDumpSupported = hds.supportsRemoteHeapDump(application);
-            }
-            cpuMonitoringSupported = jvm.isCpuMonitoringSupported();
-            gcMonitoringSupported = jvm.isCollectionTimeSupported();
-            memoryMonitoringSupported = jvm.isMemoryMonitoringSupported();
-            classMonitoringSupported = jvm.isClassMonitoringSupported();
-            threadsMonitoringSupported = jvm.isThreadMonitoringSupported();
-            if (memoryMonitoringSupported) {
-                String[] names = jvm.getGenName();
-                heapName = names[0];
-                permgenName = names[1];
-            }
-            processorsCount = jvm.getAvailableProcessors();
+        HeapDumpSupport hds = HeapDumpSupport.getInstance();
+        if (application.isLocalApplication()) {
+            takeHeapDumpSupported = hds.supportsHeapDump(application);
+        } else {
+            takeHeapDumpSupported = hds.supportsRemoteHeapDump(application);
         }
+        cpuMonitoringSupported = jvm.isCpuMonitoringSupported();
+        gcMonitoringSupported = jvm.isCollectionTimeSupported();
+        memoryMonitoringSupported = jvm.isMemoryMonitoringSupported();
+        classMonitoringSupported = jvm.isClassMonitoringSupported();
+        threadsMonitoringSupported = jvm.isThreadMonitoringSupported();
+        if (memoryMonitoringSupported) {
+            String[] names = jvm.getGenName();
+            heapName = names[0];
+            permgenName = names[1];
+        }
+        processorsCount = jvm.getAvailableProcessors();
 
         memoryMXBean = null;
         JmxModel jmxModel = JmxModelFactory.getJmxModelFor(application);
@@ -540,7 +537,7 @@ final class ApplicationMonitorModel {
     }
 
     private void fireChange() {
-        final List<ChangeListener> list = new ArrayList();
+        final List<ChangeListener> list = new ArrayList<>();
         synchronized (listeners) { list.addAll(listeners); }
         for (ChangeListener l : list) l.stateChanged(new ChangeEvent(this));
     }
@@ -552,7 +549,7 @@ final class ApplicationMonitorModel {
         this.source = source;
         this.live = live;
 
-        listeners = Collections.synchronizedList(new ArrayList());
+        listeners = Collections.synchronizedList(new ArrayList<>());
     }
 
 }
