@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -71,10 +71,7 @@ public class TruffleStackTraces {
     public abstract static class StackTrace {
 
         private final Instance thread;
-        final Heap heap;
-
-        private StackTrace(Heap h, Instance t) {
-            heap = h;
+        private StackTrace(Instance t) {
             thread = t;
         }
 
@@ -90,13 +87,13 @@ public class TruffleStackTraces {
         private final String name;
         private final List<FieldValue> fieldValues;
 
-        private Frame(Heap heap, Instance callTarget, TruffleFrame localFrame) {
-            name = getFrameName(callTarget, heap);
+        private Frame(Instance callTarget, TruffleFrame localFrame) {
+            name = getFrameName(callTarget);
             fieldValues = localFrame.getFieldValues();
         }
 
-        private Frame(Heap heap, Instance callTarget, Instance localFrame) {
-            name = getFrameName(callTarget, heap);
+        private Frame(Instance callTarget, Instance localFrame) {
+            name = getFrameName(callTarget);
             fieldValues = new TruffleFrame(localFrame).getFieldValues();
         }
 
@@ -108,31 +105,31 @@ public class TruffleStackTraces {
             return fieldValues;
         }
 
-        private static String getFrameName(Instance callTarget, Heap heap) {
+        private static String getFrameName(Instance callTarget) {
             Instance rootNode = (Instance) callTarget.getValueOfField("rootNode"); // NOI18N
 
             if (rootNode != null) {
-                String name = DetailsUtils.getInstanceString(rootNode, heap);
+                String name = DetailsUtils.getInstanceString(rootNode);
                 Instance sourceSection = getSourceSection(rootNode);
                 if (sourceSection != null) {
                     Instance source = (Instance) sourceSection.getValueOfField("source"); // NOI18N
                     if (source != null) {
-                        String fileName = getFileName(source, heap);
+                        String fileName = getFileName(source);
                         return name+" ("+fileName+":"+getLineNumber(sourceSection, source)+")"; // NOI18N
                     }
                 }
                 return name;
             }
-            return DetailsUtils.getInstanceString(callTarget, heap);
+            return DetailsUtils.getInstanceString(callTarget);
         }
     }
 
-    private static String getFileName(Instance source, Heap heap) {
+    private static String getFileName(Instance source) {
         Object key = source.getValueOfField("key"); // NOI18N
         if (key instanceof Instance) {
             source = (Instance) key;
         }
-        String fileName = DetailsUtils.getInstanceFieldString(source, "name", heap); // NOI18N
+        String fileName = DetailsUtils.getInstanceFieldString(source, "name"); // NOI18N
         int slash = fileName.lastIndexOf('/'); // NOI18N
 
         if (slash != -1) {
@@ -143,8 +140,7 @@ public class TruffleStackTraces {
 
     private static Instance getSourceSection(Instance rootNode) {
         if (rootNode == null) return null;
-        for (Object fv : rootNode.getFieldValues()) {
-            FieldValue fieldVal  = (FieldValue) fv;
+        for (FieldValue fieldVal : rootNode.getFieldValues()) {
 
             if ("sourceSection".equals(fieldVal.getField().getName())) { // NOI18N
                 Instance sc = ((ObjectFieldValue)fieldVal).getInstance();
@@ -162,10 +158,10 @@ public class TruffleStackTraces {
         Instance textmap = (Instance) source.getValueOfField("textMap"); // NOI18N
         if (textmap != null) {
             PrimitiveArrayInstance nlOffsets = (PrimitiveArrayInstance) textmap.getValueOfField("nlOffsets"); // NOI18N
-            List vals = nlOffsets.getValues();
+            List<String> vals = nlOffsets.getValues();
 
             for (int i=0; i<vals.size(); i++) {
-                Integer off = Integer.valueOf((String)vals.get(i));
+                Integer off = Integer.valueOf(vals.get(i));
 
                 if (off>=charIndex) {
                     return String.valueOf(i);
@@ -173,10 +169,19 @@ public class TruffleStackTraces {
             }
             return String.valueOf(vals.size());
         }
-        return "0"; // NOI18N
+        return "1"; // NOI18N
     }
 
-    private static Instance getSingleton(String javaClass, Heap heap) {
+    private static Instance getSingleton(Heap heap, String... fqns) {
+        for (String fqn : fqns) {
+            Instance i = getSingleton(heap, fqn);
+
+            if (i != null) return i;
+        }
+        return null;
+    }
+
+    private static Instance getSingleton(Heap heap, String javaClass) {
         JavaClass jcls = heap.getJavaClassByName(javaClass);
 
         if (jcls != null) {
@@ -184,16 +189,25 @@ public class TruffleStackTraces {
             subClasses.add(jcls);
 
             for (JavaClass jc : subClasses) {
-                List instances = jc.getInstances();
+                List<Instance> instances = jc.getInstances();
 
                 if (instances.size() == 1) {
-                    return (Instance) instances.get(0);
+                    return instances.get(0);
                 }
             }
         }
         return null;
     }
 
+    private static JavaClass getJavaClass(Heap heap, String... fqns) {
+        for (String fqn : fqns) {
+            JavaClass jcls = heap.getJavaClassByName(fqn);
+
+            if (jcls != null) return jcls;
+        }
+        return null;
+    }
+
     // implementation for DefaultTruffleRuntime
     private static class DefaultTruffleRuntime {
 
@@ -203,7 +217,7 @@ public class TruffleStackTraces {
         private Collection<StackTrace> truffleStackTraces;
 
         private DefaultTruffleRuntime(Heap heap) {
-            Instance runtime = getSingleton(TRUFFLE_RUNTIME_FQN, heap);
+            Instance runtime = getSingleton(heap, TRUFFLE_RUNTIME_FQN);
 
             if (runtime != null) {
                 Instance stackTraces = (Instance) runtime.getValueOfField("stackTraces"); // NOI18N
@@ -221,7 +235,7 @@ public class TruffleStackTraces {
         }
 
         private Collection<StackTrace> getStackTraces(Heap heap, Instance stackTraces) {
-            Collection<StackTrace> traces = new ArrayList();
+            Collection<StackTrace> traces = new ArrayList<>();
             JavaClass threadCls = heap.getJavaClassByName(THREAD_FQN);
             Collection<JavaClass> allThreadCls = threadCls.getSubClasses();
 
@@ -234,7 +248,7 @@ public class TruffleStackTraces {
                     Instance topFrame = getTruffleFrameInstance(thread, stackTraces);
 
                     if (topFrame != null) {
-                        traces.add(new DefaultStackTrace(heap, thread, topFrame));
+                        traces.add(new DefaultStackTrace(thread, topFrame));
                     }
                 }
             }
@@ -280,18 +294,18 @@ public class TruffleStackTraces {
         private final Instance topFrame;
         private List<Frame> frames;
 
-        private DefaultStackTrace(Heap h, Instance t, Instance f) {
-            super(h, t);
+        private DefaultStackTrace(Instance t, Instance f) {
+            super(t);
             topFrame = f;
         }
 
         public synchronized List<Frame> getFrames() {
             if (frames == null) {
                 Instance frame = topFrame;
-                frames = new ArrayList();
+                frames = new ArrayList<>();
 
                 do {
-                    frames.add(new DefaultFrame(heap, frame));
+                    frames.add(new DefaultFrame(frame));
                     frame = (Instance) frame.getValueOfField("callerFrame"); // NOI18N
                 } while (frame != null);
             }
@@ -301,10 +315,9 @@ public class TruffleStackTraces {
 
     private static class DefaultFrame extends Frame {
 
-        private DefaultFrame(Heap heap, Instance frame) {
-            super(heap,
-                    (Instance) frame.getValueOfField("target"), // NOI18N
-                    (Instance) frame.getValueOfField("frame") // NOI18N
+        private DefaultFrame(Instance frame) {
+            super((Instance) frame.getValueOfField("target"), // NOI18N
+                  (Instance) frame.getValueOfField("frame") // NOI18N
             );
         }
     }
@@ -329,17 +342,12 @@ public class TruffleStackTraces {
 
         private HotSpotTruffleRuntime(Heap h) {
             heap = h;
-            hotSpotRuntime = getSingleton(HOTSPOT_TRUFFLE_RUNTIME_FQN, heap);
-            if (hotSpotRuntime == null) {
-                hotSpotRuntime = getSingleton(HOTSPOT_TRUFFLE_RUNTIME1_FQN, heap);
-            }
-            if (hotSpotRuntime == null) {
-                hotSpotRuntime = getSingleton(GRAAL_TRUFFLE_RUNTIME_FQN, heap);
-            }
+            hotSpotRuntime = getSingleton(heap, HOTSPOT_TRUFFLE_RUNTIME_FQN,
+                    HOTSPOT_TRUFFLE_RUNTIME1_FQN, GRAAL_TRUFFLE_RUNTIME_FQN);
         }
 
         private boolean isHotSpotTruffleRuntime() {
-            return hotSpotRuntime != null && FrameVisitor.getFrameClass(heap) != null;
+            return hotSpotRuntime != null;
         }
 
         private void computeStackTrace(Heap heap, FrameVisitor visitor) {
@@ -357,7 +365,7 @@ public class TruffleStackTraces {
                             Map<Integer, List<JavaFrameGCRoot>> localsMap = javaFrameMap.get(threadRoot);
 
                             if (localsMap != null) {
-                                HotSpotStackTrace hsStackTrace = new HotSpotStackTrace(heap, threadInstance);
+                                HotSpotStackTrace hsStackTrace = new HotSpotStackTrace(threadInstance);
                                 for (int i = 0; i < stack.length; i++) {
                                     StackTraceElement stackElement = stack[i];
                                     List<JavaFrameGCRoot> locals = localsMap.get(Integer.valueOf(i));
@@ -378,7 +386,7 @@ public class TruffleStackTraces {
         }
 
         private Map<ThreadObjectGCRoot, Map<Integer, List<JavaFrameGCRoot>>> computeJavaFrameMap(Collection<GCRoot> roots) {
-            Map<ThreadObjectGCRoot, Map<Integer, List<JavaFrameGCRoot>>> javaFrameMap = new HashMap();
+            Map<ThreadObjectGCRoot, Map<Integer, List<JavaFrameGCRoot>>> javaFrameMap = new HashMap<>();
 
             for (GCRoot root : roots) {
                 if (GCRoot.JAVA_FRAME.equals(root.getKind())) {
@@ -389,7 +397,7 @@ public class TruffleStackTraces {
                     List<JavaFrameGCRoot> locals;
 
                     if (stackMap == null) {
-                        stackMap = new HashMap();
+                        stackMap = new HashMap<>();
                         javaFrameMap.put(threadObj, stackMap);
                     }
                     locals = stackMap.get(frameNo);
@@ -437,17 +445,19 @@ public class TruffleStackTraces {
             Instance callTarget = findLocalInstance(callTargetFrame,
                                     DEFAULT_CALL_TARGET_FQN, OPTIMIZED_CALL_TARGET_FQN, ENT_OPTIMIZED_CALL_TARGET_FQN,
                                     OPTIMIZED_CALL_TARGET1_FQN, OPTIMIZED_CALL_TARGET2_FQN);
-            TruffleFrame localFrame = findLocalFrame(callNodeFrame);
+            TruffleFrame localFrame = findLocalFrame(callTargetFrame);
+            if (localFrame == null)
+                localFrame = findLocalFrame(callNodeFrame);
 
             if (callTarget != null && localFrame != null) {
-                return new Frame(heap, callTarget, localFrame);
+                return new Frame(callTarget, localFrame);
             }
             callTarget = findLocalInstance(callNodeFrame,
                                     DEFAULT_CALL_TARGET_FQN, OPTIMIZED_CALL_TARGET_FQN, ENT_OPTIMIZED_CALL_TARGET_FQN,
                                     OPTIMIZED_CALL_TARGET1_FQN, OPTIMIZED_CALL_TARGET2_FQN);
             localFrame = findLocalFrame(callTargetFrame);
             if (callTarget != null && localFrame != null) {
-                return new Frame(heap, callTarget, localFrame);
+                return new Frame(callTarget, localFrame);
             }
             return null;
         }
@@ -456,7 +466,7 @@ public class TruffleStackTraces {
             if (isHotSpotTruffleRuntime() && truffleStackTraces == null) {
                 FrameVisitor visitor = new FrameVisitor(this, heap, 0);
 
-                truffleStackTraces = new ArrayList();
+                truffleStackTraces = new ArrayList<>();
 
                 computeStackTrace(heap, visitor);
             }
@@ -469,9 +479,9 @@ public class TruffleStackTraces {
 
         List<Frame> frames;
 
-        public HotSpotStackTrace(Heap h, Instance t) {
-            super(h, t);
-            frames = new ArrayList();
+        HotSpotStackTrace(Instance t) {
+            super(t);
+            frames = new ArrayList<>();
         }
 
         @Override
@@ -490,6 +500,18 @@ public class TruffleStackTraces {
         private final String methodName;
         private final String signature;
 
+        private JavaMethod() {
+            className = null;
+            methodName = null;
+            signature = null;
+        }
+
+        private JavaMethod(String name, String method, String sig) {
+            className = name;
+            methodName = method;
+            signature = sig;
+        }
+
         private JavaMethod(Heap heap, JavaClass frameClass, String field) {
             this(heap, (Instance) frameClass.getValueOfStaticField(field));
         }
@@ -498,8 +520,8 @@ public class TruffleStackTraces {
             if (method != null) {
                 Instance javaClass = (Instance) method.getValueOfField("clazz");   // NOI18N
                 className = heap.getJavaClassByID(javaClass.getInstanceId()).getName();
-                methodName = DetailsUtils.getInstanceFieldString(method, "name", heap); // NOI18N
-                signature = DetailsUtils.getInstanceFieldString(method, "signature", heap); // NOI18N
+                methodName = DetailsUtils.getInstanceFieldString(method, "name"); // NOI18N
+                signature = DetailsUtils.getInstanceFieldString(method, "signature"); // NOI18N
             } else {
                 className = null;
                 methodName = null;
@@ -508,6 +530,9 @@ public class TruffleStackTraces {
         }
 
         private boolean isMethod(StackTraceElement frame) {
+            if (className == null) {
+                return frame.getMethodName().equals(methodName);
+            }
             return frame.getClassName().equals(className) && frame.getMethodName().equals(methodName);
         }
     }
@@ -516,6 +541,7 @@ public class TruffleStackTraces {
 
         private static final String GRAAL_FRAME_INSTANCE_FQN = "org.graalvm.compiler.truffle.GraalFrameInstance"; // NOI18N
         private static final String GRAAL_FRAME_INSTANCE1_FQN = "org.graalvm.compiler.truffle.runtime.GraalFrameInstance";  // NOI18N
+        private static final String GRAAL_RUNTIME_SUPPORT = "org.graalvm.compiler.truffle.runtime.GraalRuntimeSupport"; // NOI18N
 
         private final HotSpotTruffleRuntime visitor;
         private final JavaMethod callOSRMethod;
@@ -526,6 +552,7 @@ public class TruffleStackTraces {
         private final JavaMethod callDirectMethod;
         private final JavaMethod callIndirectMethod;
         private final JavaMethod callInlinedMethod;
+        private final JavaMethod callInlinedCallMethod;
         private final JavaMethod callInlinedAgnosticMethod;
         private final JavaMethod callInliningForcedMethod;
         private int skipFrames;
@@ -534,26 +561,54 @@ public class TruffleStackTraces {
         FrameVisitor(HotSpotTruffleRuntime visitor, Heap heap, int skip) {
             this.visitor = visitor;
             JavaClass frameClass = getFrameClass(heap);
-            callOSRMethod = new JavaMethod(heap, frameClass, "CALL_OSR_METHOD");  // NOI18N
-            callTargetMethod = new JavaMethod(heap, frameClass, "CALL_TARGET_METHOD");  // NOI18N
+            if (frameClass != null) {
+                callOSRMethod = new JavaMethod(heap, frameClass, "CALL_OSR_METHOD");  // NOI18N
+                callTargetMethod = new JavaMethod(heap, frameClass, "CALL_TARGET_METHOD");  // NOI18N
 
-            callNodeMethod = new JavaMethod(heap, frameClass, "CALL_NODE_METHOD");  // NOI18N
+                callNodeMethod = new JavaMethod(heap, frameClass, "CALL_NODE_METHOD");  // NOI18N
 
-            callDirectMethod = new JavaMethod(heap, frameClass, "CALL_DIRECT");  // NOI18N
-            callIndirectMethod = new JavaMethod(heap, frameClass, "CALL_INDIRECT");  // NOI18N
-            callInlinedMethod = new JavaMethod(heap, frameClass, "CALL_INLINED");  // NOI18N
-            callInlinedAgnosticMethod = new JavaMethod(heap, frameClass, "CALL_INLINED_AGNOSTIC");  // NOI18N
-            callInliningForcedMethod = new JavaMethod(heap, frameClass, "CALL_INLINED_FORCED");  // NOI18N
+                callDirectMethod = new JavaMethod(heap, frameClass, "CALL_DIRECT");  // NOI18N
+                callIndirectMethod = new JavaMethod(heap, frameClass, "CALL_INDIRECT");  // NOI18N
+                callInlinedMethod = new JavaMethod(heap, frameClass, "CALL_INLINED");  // NOI18N
+                callInlinedCallMethod = new JavaMethod(heap, frameClass, "CALL_INLINED_CALL");  // NOI18N
+                callInlinedAgnosticMethod = new JavaMethod(heap, frameClass, "CALL_INLINED_AGNOSTIC");  // NOI18N
+                callInliningForcedMethod = new JavaMethod(heap, frameClass, "CALL_INLINED_FORCED");  // NOI18N
+            } else {
+                JavaClass callTargetClass = getJavaClass(heap,
+                        HotSpotTruffleRuntime.OPTIMIZED_CALL_TARGET_FQN,
+                        HotSpotTruffleRuntime.ENT_OPTIMIZED_CALL_TARGET_FQN,
+                        HotSpotTruffleRuntime.OPTIMIZED_CALL_TARGET1_FQN,
+                        HotSpotTruffleRuntime.OPTIMIZED_CALL_TARGET2_FQN);
+                String callTargetFqn = callTargetClass == null ? null : callTargetClass.getName();
+                callOSRMethod = new JavaMethod(null, "callProxy", "");  // NOI18N
+                callTargetMethod = new JavaMethod(callTargetFqn, "executeRootNode", "");  // NOI18N
+
+                callNodeMethod = new JavaMethod();  // NOI18N
+
+                callDirectMethod = new JavaMethod(callTargetFqn, "callDirect", "");  // NOI18N
+                callIndirectMethod = new JavaMethod(callTargetFqn, "callIndirect", "");  // NOI18N
+                callInlinedMethod = new JavaMethod(callTargetFqn, "callInlined", "");  // NOI18N
+                JavaClass runtimeSupport = heap.getJavaClassByName(GRAAL_RUNTIME_SUPPORT);
+                if (runtimeSupport != null) {
+                    Object val = runtimeSupport.getValueOfStaticField("CALL_INLINED_METHOD_NAME");  // NOI18N
+
+                    if (val instanceof Instance) {
+                        String methodName = DetailsUtils.getInstanceString((Instance) val);
+                        callInlinedCallMethod = new JavaMethod(GRAAL_RUNTIME_SUPPORT, methodName, "");  // NOI18N
+                    } else {
+                        callInlinedCallMethod = new JavaMethod();
+                    }
+                } else {
+                    callInlinedCallMethod = new JavaMethod();
+                }
+                callInlinedAgnosticMethod = new JavaMethod();
+                callInliningForcedMethod = new JavaMethod();
+            }
             skipFrames = skip;
         }
 
         private static JavaClass getFrameClass(Heap heap) {
-            JavaClass frameClass = heap.getJavaClassByName(GRAAL_FRAME_INSTANCE_FQN);
-
-            if (frameClass == null) {
-                frameClass = heap.getJavaClassByName(GRAAL_FRAME_INSTANCE1_FQN);
-            }
-            return frameClass;
+            return getJavaClass(heap, GRAAL_FRAME_INSTANCE_FQN, GRAAL_FRAME_INSTANCE1_FQN);
         }
 
         private Frame visitFrame(StackTraceElement frame, List<JavaFrameGCRoot> locals) {
@@ -561,18 +616,19 @@ public class TruffleStackTraces {
                 // we ignore OSR frames.
                 skipFrames++;
             } else if (callTargetMethod.isMethod(frame)) {
-                try {
-                    if (skipFrames == 0) {
+                if (skipFrames == 0) {
+                    try {
                         return visitor.visitFrame(locals, callNodeFrame);
-                    } else {
-                        skipFrames--;
+                    } finally {
+                        callNodeFrame = null;
                     }
-                } finally {
-                    callNodeFrame = null;
+                } else {
+                    skipFrames--;
                 }
-            } else if (callNodeMethod.isMethod(frame) || callDirectMethod.isMethod(frame) ||
-                    callIndirectMethod.isMethod(frame) || callInlinedMethod.isMethod(frame) ||
-                    callInlinedAgnosticMethod.isMethod(frame) || callInliningForcedMethod.isMethod(frame)) {
+            } else if (callNodeMethod.isMethod(frame) || callDirectMethod.isMethod(frame)
+                    || callIndirectMethod.isMethod(frame) || callInlinedMethod.isMethod(frame)
+                    || callInlinedCallMethod.isMethod(frame)
+                    || callInlinedAgnosticMethod.isMethod(frame) || callInliningForcedMethod.isMethod(frame)) {
                 callNodeFrame = locals;
             }
             return null;
