@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -24,13 +24,13 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.dynamicobject;
 
-import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
 import org.graalvm.visualvm.lib.jfluid.heap.ArrayItemValue;
 import org.graalvm.visualvm.lib.jfluid.heap.Field;
 import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
@@ -91,11 +91,11 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
     
     public List<FieldValue> getReferences() {
-        List<FieldValue> dynObjRefs = new ArrayList();
+        List<FieldValue> dynObjRefs = new ArrayList<>();
 
         if (getShape() != null) {
             List<Value> refs = instance.getReferences();
-            Set<Instance> foundRefs = new HashSet();
+            Set<Instance> foundRefs = new HashSet<>();
 
             for (Value ref : refs) {
                 Instance instanceRef = ref.getDefiningInstance();
@@ -155,26 +155,26 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
     
     @Override
-    public String getType(Heap heap) {
+    public String getType() {
         if (type == null) {
-            type = computeType(heap);
+            type = computeType();
             if (type == null) type = "<unknown type>"; // NOI18N
         }
         return type;
     }
 
     @Override
-    public long getTypeId(Heap heap) {
+    public long getTypeId() {
         return getShape().getInstanceId();
     }
     
-    protected String computeType(Heap heap) {
-        return DetailsSupport.getDetailsString(getShape(), heap);
+    protected String computeType() {
+        return DetailsSupport.getDetailsString(getShape());
     }
     
-    public static String getType(Instance instance, Heap heap) {
+    public static String getType(Instance instance) {
         Instance shape = getShape(instance);
-        return DetailsSupport.getDetailsString(shape, heap);
+        return DetailsSupport.getDetailsString(shape);
     }
     
     @Override
@@ -219,8 +219,8 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         if (propertyMap == null) propertyMap = getValueofFields(instance, "shape", "propertyMap"); // NOI18N
         if (propertyMap != null) {
 //            properties = new ArrayList();
-            values = new ArrayList();
-            staticValues = new ArrayList();
+            values = new ArrayList<>();
+            staticValues = new ArrayList<>();
             boolean hasExtRef = hasField(instance.getJavaClass(), "extRef");    // NOI18N
             boolean hasShortNames = hasField(instance.getJavaClass(), "o0");    // NOI18N
 
@@ -261,10 +261,10 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private boolean hasField(JavaClass jcls, String name) {
-        List fields = jcls.getFields();
+        List<Field> fields = jcls.getFields();
 
         for (int i = fields.size()-1; i>=0; i--) {
-            Field f = (Field) fields.get(i);
+            Field f = fields.get(i);
 
             if (f.getName().equals(name)) {
                 return true;
@@ -286,7 +286,9 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 while (objTypeCls != null) {
                     JavaClass superObjType = objTypeCls.getSuperClass();
 
-                    if (superObjType == null || OBJECT_TYPE_FQN.equals(superObjType.getName())) {
+                    if (superObjType == null
+                       || OBJECT_TYPE_FQN.equals(superObjType.getName())
+                       || Object.class.getName().equals(superObjType.getName())) {
                         return objTypeCls;
                     }
                     objTypeCls = superObjType;
@@ -326,7 +328,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getHashMapValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
         Object val = propertyMap.getValueOfField("table");  // NOI18N
 
         if (val != null && val instanceof ObjectArrayInstance) {
@@ -346,7 +348,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getConsListValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
 
         for (Instance node = propertyMap; node != null; node = (Instance) node.getValueOfField("car")) {    // NOI18N
             Object value = node.getValueOfField("cdr"); // NOI18N
@@ -359,7 +361,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getTrieValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
         Object root = propertyMap.getValueOfField("root");  // NOI18N
 
         getNodeValues(root, mapValues);
@@ -374,9 +376,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
             if (entries instanceof ObjectArrayInstance) {
                 ObjectArrayInstance table = (ObjectArrayInstance) entries;
 
-                for (Object el : table.getValues()) {
-                    Instance entry = (Instance) el;
-
+                for (Instance entry : table.getValues()) {
                     if (!getNodeValues(entry, nodeValues)) {
                         Object value = entry.getValueOfField("value");  // NOI18N
                         if (value instanceof Instance) {
@@ -446,7 +446,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         private Property(Instance p, boolean extRef, boolean shortNames) {
             assert p.getJavaClass().getName().equals(PROPERTY_FQN);
             property = p;
-            propertyName = DetailsUtils.getInstanceString(p, null);
+            propertyName = DetailsUtils.getInstanceString(p);
             location = (Instance) property.getValueOfField("location"); // NOI18N
             hasExtRef = extRef;
             hasShortNames = shortNames;
@@ -498,7 +498,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                     // Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");
                     ObjectArrayInstance arr = getObjectStore(dynamicObject);
 
-                    return getObjectFieldValue(dynamicObject, (Instance) arr.getValues().get(index));
+                    return getObjectFieldValue(dynamicObject, arr.getValues().get(index));
                 }
                 if (className.contains("LongArrayLocation")) {  // NOI18N
                     Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
@@ -511,7 +511,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                     } else {
                         // primext is long[]
                         arr = (PrimitiveArrayInstance) dynamicObject.getValueOfField("primext"); // NOI18N
-                        return getFieldValue(dynamicObject, (String) arr.getValues().get(index));
+                        return getFieldValue(dynamicObject, arr.getValues().get(index));
                     }
                 }
             }
@@ -561,8 +561,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         }
 
         private FieldValue getInstanceFieldValue(Instance dynObj, Instance i, String fieldName) {
-            for (Object f : i.getFieldValues()) {
-                FieldValue fieldValue = (FieldValue) f;
+            for (FieldValue fieldValue : i.getFieldValues()) {
 
                 if (fieldValue.getField().getName().equals(fieldName)) {
                     return createFieldValue(dynObj, fieldValue);
@@ -690,11 +689,10 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 Instance actualLoc = (Instance) loc.getValueOfField("actualLocation");  // NOI18N
                 return getValueImpl(actualLoc, dynamicObject);
             }
-            if (className.contains("ObjectFieldLocation")) {    // NOI18N
-                Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                int objectIndex = hasExtRef ? index : index + 2;
-                String prefix = hasShortNames ? "o" : "object";         // NOI18N
-                FieldValue ret = getInstanceFieldValue(dynamicObject, prefix + objectIndex);
+            if (className.contains("ObjectFieldLocation")               // NOI18N
+                || className.contains("ExtensionArrayLocation")) {      // NOI18N
+                String fName = getEnterpriseObjectFieldName(loc);
+                FieldValue ret = getInstanceFieldValue(dynamicObject, fName);
                 if (ret == null) {
                     // extVal is encoded as non-existing index
                     return getObjectFieldValue(dynamicObject, (Instance) dynamicObject.getValueOfField("extVal"));  // NOI18N
@@ -702,77 +700,115 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 return ret;
             }
             if (className.contains("IntFieldLocation")) { // NOI18N
-                Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                int objectIndex = hasExtRef ? index : index + 1;
-                String prefix = hasShortNames ? "p" : "primitive";      // NOI18N
-                return getInstanceFieldValue(dynamicObject, prefix + objectIndex);
+                String fName = getEnterprisePrimitiveFieldName(loc);
+                return getInstanceFieldValue(dynamicObject, fName);
             }
             if (className.contains("BooleanFieldLocation")) {   // NOI18N
-                Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                int objectIndex = hasExtRef ? index : index + 1;
-                String prefix = hasShortNames ? "p" : "primitive";      // NOI18N
-                Integer i1 = (Integer) dynamicObject.getValueOfField(prefix + objectIndex);
+                String fName = getEnterprisePrimitiveFieldName(loc);
+                Integer i1 = (Integer) dynamicObject.getValueOfField(fName);
                 return getFieldValue(dynamicObject, Boolean.toString(i1.intValue() != 0));
             }
-            if (className.contains("DoubleFieldLocation")) {    // NOI18N
-                Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                int objectIndex = hasExtRef ? index : index + 1;
-                String prefix = hasShortNames ? "p" : "primitive";      // NOI18N
-                Number i1 = (Number) dynamicObject.getValueOfField(prefix + objectIndex);
+            if (className.contains("DoubleFieldLocation")        // NOI18N
+                || className.contains("LongFieldLocation")) {    // NOI18N
+                String fName = getEnterprisePrimitiveFieldName(loc);
+                Number i1 = (Number) dynamicObject.getValueOfField(fName);
                 long val;
+                String valString;
 
                 if (i1 instanceof Long) {
                     val = i1.longValue();
                 } else {
-                    Integer i2 = (Integer) dynamicObject.getValueOfField(prefix + (objectIndex + 1));
+                    Integer i2 = (Integer) getValueOfNextField(dynamicObject, fName);
                     val = getLong(i1.intValue(), i2);
                 }
-                return getFieldValue(dynamicObject, getDouble(val));
-            }
-            if (className.contains("LongFieldLocation")) {    // NOI18N
-                Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                int objectIndex = hasExtRef ? index : index + 1;
-                String prefix = hasShortNames ? "p" : "primitive";    // NOI18N
-                Number i1 = (Number) dynamicObject.getValueOfField(prefix + objectIndex);
-                long val;
-
-                if (i1 instanceof Long) {
-                    val = i1.longValue();
+                if (className.contains("LongFieldLocation")) {      // NOI18N
+                    valString = Long.toString(val);
                 } else {
-                    Integer i2 = (Integer) dynamicObject.getValueOfField(prefix + (objectIndex + 1));
-                    val = getLong(i1.intValue(), i2);
+                    valString = getDouble(val);
                 }
-                return getFieldValue(dynamicObject, Long.toString(val));
+                return getFieldValue(dynamicObject, valString);
             }
             if (className.contains("ObjectArrayLocation")) {    // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
                 ObjectArrayInstance arr = getEnterpriseObjectStore(dynamicObject);
-                return getObjectFieldValue(dynamicObject, (Instance) arr.getValues().get(index));
+                return getObjectFieldValue(dynamicObject, arr.getValues().get(index));
             }
             if (className.contains("IntArrayLocation")) {   // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
-                return getFieldValue(dynamicObject, (String) arr.getValues().get(index));
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
+                return getFieldValue(dynamicObject, arr.getValues().get(index));
             }
             if (className.contains("DoubleArrayLocation")) {    // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
                 return getFieldValue(dynamicObject, getDouble(getLong(arr, index)));
             }
             if (className.contains("LongArrayLocation")) {    // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
                 return getFieldValue(dynamicObject, Long.toString(getLong(arr, index)));
             }
             return null;
         }
 
+        private PrimitiveArrayInstance getPrimitiveArray(Instance loc, Instance dynamicObject) {
+            Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
+            PrimitiveArrayInstance arr;
+            if (actualLoc == null) {
+                arr =  (PrimitiveArrayInstance) dynamicObject.getValueOfField("extVal");    // NOI18N
+            } else {
+                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
+                arr = (PrimitiveArrayInstance) ((ObjectFieldValue)arrayVal).getInstance();
+            }
+            return arr;
+        }
+
+        private Object getValueOfNextField(Instance dynamicObject, String fieldName) {
+            int i = fieldName.length()-1;
+            for (; i>=0 && Character.isDigit(fieldName.charAt(i)); i--);
+            assert i < fieldName.length()-1 : "Invalid fname "+fieldName;
+            int fIndex = Integer.parseInt(fieldName.substring(++i));
+
+            return dynamicObject.getValueOfField(fieldName.substring(0,i)+(fIndex+1));
+        }
+
+        private String getEnterpriseObjectFieldName(Instance location) {
+            String fName = getEnterpriseFieldNameFromFieldInfo(location);
+            if (fName == null) {
+                Integer index = (Integer) location.getValueOfField("index"); // NOI18N
+                int objectIndex = hasExtRef ? index : index + 2;
+                String prefix = hasShortNames ? "o" : "object";         // NOI18N
+                fName = prefix + objectIndex;
+            }
+            return fName;
+        }
+
+        private String getEnterprisePrimitiveFieldName(Instance location) {
+            String fName = getEnterpriseFieldNameFromFieldInfo(location);
+            if (fName == null) {
+                Integer index = (Integer) location.getValueOfField("index"); // NOI18N
+                int objectIndex = hasExtRef ? index : index + 1;
+                String prefix = hasShortNames ? "p" : "primitive";      // NOI18N
+                fName = prefix + objectIndex;
+            }
+            return fName;
+        }
+
+        private String getEnterpriseFieldNameFromFieldInfo(Instance location) {
+            Object fieldInfo = location.getValueOfField("field");     // NOI18N
+            if (fieldInfo instanceof Instance) {
+                for (Object fv : ((Instance)fieldInfo).getFieldValues()) {
+                    if (fv instanceof ObjectFieldValue) {
+                        Instance ifv = ((ObjectFieldValue)fv).getInstance();
+                        if (String.class.getName().equals(ifv.getJavaClass().getName())) {
+                            return DetailsSupport.getDetailsString(ifv);
+                        }
+                    }
+                }
+            }
+            return null;
+        }
+
         private ObjectArrayInstance getEnterpriseObjectStore(Instance dynamicObject) {
             String fieldName = hasExtRef ? "extRef" : "object1"; // NOI18N
 
@@ -780,11 +816,11 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         }
 
         private FieldValue getObfuscatedEnperpriseValue(Instance loc, String className, Instance dynamicObject) {
-            List fields = loc.getFieldValues();
+            List<FieldValue> fields = loc.getFieldValues();
 
             if (fields.size() == 2) {
-                FieldValue v0 = (FieldValue) fields.get(0);
-                FieldValue v1 = (FieldValue) fields.get(1);
+                FieldValue v0 = fields.get(0);
+                FieldValue v1 = fields.get(1);
                 Type t0 = v0.getField().getType();
                 Type t1 = v1.getField().getType();
 
@@ -884,11 +920,11 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                     // long, double
                     return getFieldValue(dynamicObject, getDouble(getLong(arr, index)));
                 }
-                return getFieldValue(dynamicObject, (String) arr.getValues().get(index));
+                return getFieldValue(dynamicObject, arr.getValues().get(index));
             }
             if (array instanceof ObjectArrayInstance) {
                 ObjectArrayInstance arr = (ObjectArrayInstance) array;
-                return getObjectFieldValue(dynamicObject, (Instance) arr.getValues().get(index));
+                return getObjectFieldValue(dynamicObject, arr.getValues().get(index));
             }
             return null;
         }
@@ -966,10 +1002,10 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         }
 
         private FieldValue getDynamicObjectField(Instance dynamicObject, int index, boolean objectType) {
-            List fields = dynamicObject.getJavaClass().getFields();
+            List<Field> fields = dynamicObject.getJavaClass().getFields();
 
             for (int i = fields.size()-1; i>=0; i--) {
-                Field f = (Field) fields.get(i);
+                Field f = fields.get(i);
 
                 if (f.getType().getName().equals("object") == objectType) { // NOI18N
                     if (index == 0) {
@@ -982,10 +1018,9 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         }
 
         private FieldValue getValueOfField(Instance dynamicObject, Field field) {
-             List fieldVals = dynamicObject.getFieldValues();
+             List<FieldValue> fieldVals = dynamicObject.getFieldValues();
 
-             for (int i=0; i<fieldVals.size(); i++) {
-                 FieldValue fv = (FieldValue) fieldVals.get(i);
+             for (FieldValue fv : fieldVals) {
 
                  if (fv.getField().equals(field)) {
                      return fv;
@@ -999,9 +1034,9 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         }
 
         private static long getLong(PrimitiveArrayInstance arr, int index) {
-            List vals = arr.getValues();
-            Integer i1 = Integer.valueOf((String) vals.get(index));
-            Integer i2 = Integer.valueOf((String) vals.get(index+1));
+            List<String> vals = arr.getValues();
+            Integer i1 = Integer.valueOf(vals.get(index));
+            Integer i2 = Integer.valueOf(vals.get(index+1));
 
             return getLong(i1, i2);
         }
