@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -24,26 +24,28 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.lang.python;
 
+import java.math.BigDecimal;
+import java.math.BigInteger;
 import java.util.List;
+import java.util.Map;
+import javax.swing.Icon;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleLocalObjectNode;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleObjectFieldNode;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
-import org.graalvm.visualvm.lib.profiler.heapwalk.details.api.DetailsSupport;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleObjectNode;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleObjectReferenceNode;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleOpenNodeActionProvider;
 import org.graalvm.visualvm.heapviewer.truffle.nodes.TruffleTypeNode;
 import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
 import org.graalvm.visualvm.heapviewer.ui.HeapViewerRenderer;
-import java.util.Map;
-import javax.swing.Icon;
 import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
+import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
 import org.graalvm.visualvm.lib.jfluid.heap.ObjectFieldValue;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
+import org.graalvm.visualvm.lib.profiler.heapwalk.details.api.DetailsSupport;
 import org.graalvm.visualvm.lib.profiler.heapwalk.details.spi.DetailsUtils;
 import org.openide.util.lookup.ServiceProvider;
 
@@ -72,7 +74,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
     
     private static final int MAX_LOGVALUE_LENGTH = 160;
     
-    static String getLogicalValue(PythonObject object, String type, Heap heap) {
+    static String getLogicalValue(PythonObject object, String type) {
         String logicalValue = null;
         
         if ("ModuleSpec".equals(type)) { // NOI18N
@@ -80,7 +82,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("name".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -89,7 +91,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("path".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -98,18 +100,18 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("__name__".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
         } else if ("generator".equals(type)) { // NOI18N
-            logicalValue = DetailsUtils.getInstanceFieldString(object.getInstance(), "name", heap); // NOI18N
+            logicalValue = DetailsUtils.getInstanceFieldString(object.getInstance(), "name"); // NOI18N
         } else if ("FileIO".equals(type)) { // NOI18N
             List<FieldValue> attributes = object.getAttributes();
             for (FieldValue attribute : attributes) {
                 if ("name".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -117,13 +119,13 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             Object moduleO = object.getInstance().getValueOfField("type"); // NOI18N
             if (!(moduleO instanceof Instance)) moduleO = null;
             else if (!((Instance)moduleO).getJavaClass().getName().equals("com.oracle.graal.python.builtins.objects.type.PythonClass")) moduleO = null; // NOI18N
-            logicalValue = moduleO == null ? null : DetailsUtils.getInstanceString((Instance)moduleO, heap);
+            logicalValue = moduleO == null ? null : DetailsUtils.getInstanceString((Instance)moduleO);
         } else if ("code".equals(type)) { // NOI18N
             Object callTarget = object.getInstance().getValueOfField("callTarget"); // NOI18N
             if (callTarget instanceof Instance) {
                 Object rootNode = ((Instance)callTarget).getValueOfField("rootNode"); // NOI18N
                 if (rootNode instanceof Instance) {
-                    logicalValue = DetailsUtils.getInstanceFieldString((Instance)rootNode, "functionName", heap); // NOI18N
+                    logicalValue = DetailsUtils.getInstanceFieldString((Instance)rootNode, "functionName"); // NOI18N
                 }
             }
         } else if ("FileFinder".equals(type)) { // NOI18N
@@ -131,7 +133,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("path".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -141,7 +143,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
                 if ("_raw".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
                     if (PythonObject.isPythonObject(attributeI)) {
-                        logicalValue = getLogicalValue(new PythonObject(attributeI), "FileIO", heap); // NOI18N
+                        logicalValue = getLogicalValue(new PythonObject(attributeI), "FileIO"); // NOI18N
                         break;
                     }
                 }
@@ -152,7 +154,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
                 if ("_buffer".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
                     if (PythonObject.isPythonObject(attributeI)) {
-                        logicalValue = getLogicalValue(new PythonObject(attributeI), "BufferedWriter", heap); // NOI18N
+                        logicalValue = getLogicalValue(new PythonObject(attributeI), "BufferedWriter"); // NOI18N
                         break;
                     }
                 }
@@ -162,7 +164,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("template".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -171,7 +173,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("__name".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -180,7 +182,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("name".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
@@ -189,24 +191,71 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
             for (FieldValue attribute : attributes) {
                 if ("name".equals(attribute.getField().getName()) && attribute instanceof ObjectFieldValue) { // NOI18N
                     Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
-                    logicalValue = DetailsSupport.getDetailsString(attributeI, heap);
+                    logicalValue = DetailsSupport.getDetailsString(attributeI);
                     break;
                 }
             }
         } else if ("dict".equals(type)) { // NOI18N
             List<FieldValue> attributes = object.getAttributes();
             logicalValue = attributes.size() + " pairs"; // NOI18N
+        } else if ("Decimal".equals(type)) { // NOI18N
+            String _int = null;
+            String _exp = null;
+            String _sig = null;
+            String _is_special = null;
+
+            for (FieldValue attribute : object.getAttributes()) {
+                String attrName = attribute.getField().getName();
+
+                if ("_int (hidden)".equals(attrName)) { // NOI18N
+                    _int = getAttributeValue(attribute);
+                } else if ("_exp (hidden)".equals(attrName)) { // NOI18N
+                    _exp = getAttributeValue(attribute);
+                } else if ("_sign (hidden)".equals(attrName)) { // NOI18N
+                    _sig = getAttributeValue(attribute);
+                } else if ("_is_special (hidden)".equals(attrName)) { // NOI18N
+                    _is_special = getAttributeValue(attribute);
+                }
+            }
+            if (_int != null && _exp != null && _sig != null && _is_special != null) {
+                int _sigObj = Integer.valueOf(_sig);
+
+                if (_is_special.equals(Boolean.TRUE.toString())) {
+                    // special values
+                    String sign = _sigObj == 1 ? "-" : "";      // NOI18N
+                    if ("F".equals(_exp)) {                     // NOI18N
+                        return sign + "Infinity";               // NOI18N
+                    } else if ("n".equals(_exp)) {              // NOI18N
+                        return sign + "NaN" + _int;             // NOI18N
+                    } else if ("N".equals(_exp)) {              // NOI18N
+                        return sign + "sNaN" + _int;            // NOI18N
+                    }
+                }
+                BigInteger _intObj = new BigInteger(_int);
+                int _expObj = Integer.valueOf(_exp);
+                if (_sigObj == 1) {
+                    _intObj = _intObj.negate();
+                }
+                return new BigDecimal(_intObj, -_expObj).toString();
+            }
         }
         
         if (logicalValue != null && logicalValue.length() > MAX_LOGVALUE_LENGTH)
             logicalValue = logicalValue.substring(0, MAX_LOGVALUE_LENGTH) + "..."; // NOI18N
         
         return logicalValue != null ? logicalValue :
-               DetailsSupport.getDetailsString(object.getInstance(), heap);
+               DetailsSupport.getDetailsString(object.getInstance());
     }
     
+    private static String getAttributeValue(FieldValue attribute) {
+        if (attribute instanceof ObjectFieldValue) {
+            Instance attributeI = ((ObjectFieldValue)attribute).getInstance();
+            return DetailsSupport.getDetailsString(attributeI);
+        }
+        return attribute.getValue();
+    }
     
-    private static String computeObjectName(TruffleObjectNode.InstanceBased<PythonObject> node, Heap heap) {
+    private static String computeObjectName(TruffleObjectNode.InstanceBased<PythonObject> node) {
         String typeString = node.getTypeName();
         return typeString.substring(typeString.lastIndexOf('.') + 1) + "#" + node.getInstance().getInstanceNumber(); // NOI18N
     }
@@ -221,23 +270,23 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
     
     static class PythonObjectNode extends TruffleObjectNode.InstanceBased<PythonObject> implements PythonNode {
         
-        public PythonObjectNode(PythonObject object, Heap heap) {
-            this(object, object.getType(heap));
+        PythonObjectNode(PythonObject object) {
+            this(object, object.getType());
         }
 
-        public PythonObjectNode(PythonObject robject, String type) {
+        PythonObjectNode(PythonObject robject, String type) {
             super(robject, type);
         }
         
         
         @Override
-        protected String computeObjectName(Heap heap) {
-            return PythonNodes.computeObjectName(this, heap);
+        protected String computeObjectName() {
+            return PythonNodes.computeObjectName(this);
         }
         
-        protected String computeLogicalValue(PythonObject object, String type, Heap heap) {
-            String logicalValue = PythonNodes.getLogicalValue(object, type, heap);
-            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type, heap);
+        protected String computeLogicalValue(PythonObject object, String type) {
+            String logicalValue = PythonNodes.getLogicalValue(object, type);
+            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type);
         }
         
         
@@ -260,13 +309,13 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
         }
         
         @Override
-        protected String computeObjectName(Heap heap) {
-            return PythonNodes.computeObjectName(this, heap);
+        protected String computeObjectName() {
+            return PythonNodes.computeObjectName(this);
         }
         
-        protected String computeLogicalValue(PythonObject object, String type, Heap heap) {
-            String logicalValue = PythonNodes.getLogicalValue(object, type, heap);
-            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type, heap);
+        protected String computeLogicalValue(PythonObject object, String type) {
+            String logicalValue = PythonNodes.getLogicalValue(object, type);
+            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type);
         }
         
         
@@ -283,7 +332,7 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
         }
 
         @Override
-        public HeapViewerNode createNode(PythonObject object, Heap heap) {
+        public HeapViewerNode createNode(PythonObject object) {
             String type = getType().getName();
             return new PythonNodes.PythonObjectNode(object, type);
         }
@@ -309,13 +358,13 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
         }
         
         @Override
-        protected String computeObjectName(Heap heap) {
-            return PythonNodes.computeObjectName(this, heap); // NOI18N
+        protected String computeObjectName() {
+            return PythonNodes.computeObjectName(this); // NOI18N
         }
         
-        protected String computeLogicalValue(PythonObject object, String type, Heap heap) {
-            String logicalValue = PythonNodes.getLogicalValue(object, type, heap);
-            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type, heap);
+        protected String computeLogicalValue(PythonObject object, String type) {
+            String logicalValue = PythonNodes.getLogicalValue(object, type);
+            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type);
         }
         
         
@@ -332,13 +381,13 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
         }
         
         @Override
-        protected String computeObjectName(Heap heap) {
-            return PythonNodes.computeObjectName(this, heap);
+        protected String computeObjectName() {
+            return PythonNodes.computeObjectName(this);
         }
         
-        protected String computeLogicalValue(PythonObject object, String type, Heap heap) {
-            String logicalValue = PythonNodes.getLogicalValue(object, type, heap);
-            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type, heap);
+        protected String computeLogicalValue(PythonObject object, String type) {
+            String logicalValue = PythonNodes.getLogicalValue(object, type);
+            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type);
         }
         
         
@@ -355,13 +404,13 @@ public class PythonNodes extends TruffleOpenNodeActionProvider<PythonObject, Pyt
         }
         
         @Override
-        protected String computeObjectName(Heap heap) {
-            return PythonNodes.computeObjectName(this, heap);
+        protected String computeObjectName() {
+            return PythonNodes.computeObjectName(this);
         }
         
-        protected String computeLogicalValue(PythonObject object, String type, Heap heap) {
-            String logicalValue = PythonNodes.getLogicalValue(object, type, heap);
-            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type, heap);
+        protected String computeLogicalValue(PythonObject object, String type) {
+            String logicalValue = PythonNodes.getLogicalValue(object, type);
+            return logicalValue != null ? logicalValue : super.computeLogicalValue(object, type);
         }
         
         
