@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,17 +24,16 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.lang.python;
 
-import org.graalvm.visualvm.heapviewer.truffle.dynamicobject.DynamicObject;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
-import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
 import java.util.AbstractList;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
+import org.graalvm.visualvm.heapviewer.truffle.dynamicobject.DynamicObject;
+import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
 import org.graalvm.visualvm.lib.jfluid.heap.ArrayItemValue;
 import org.graalvm.visualvm.lib.jfluid.heap.Field;
 import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
 import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
 import org.graalvm.visualvm.lib.jfluid.heap.ObjectArrayInstance;
@@ -56,6 +55,7 @@ class PythonObject extends TruffleObject.InstanceBased {
     static final String PYTHON_LIST_FQN = "com.oracle.graal.python.builtins.objects.list.PList"; // NOI18N
     static final String TREEMAP_ENTRY_FQN = "java.util.TreeMap$Entry";  // NOI18N
     static final String TREEMAP_FQN = "java.util.TreeMap";  // NOI18N
+    private static final String HASHING_STORAGE_FQN = "com.oracle.graal.python.builtins.objects.common.HashingStorage";     // NOI18N
 
     private final Instance instance;
     private final Instance storage;
@@ -91,7 +91,7 @@ class PythonObject extends TruffleObject.InstanceBased {
         array = (ObjectArrayInstance) values[5];
         map = (Instance) values[6];
         set = (Instance) values[7];
-        dictStorage = (Instance) values[8];
+        dictStorage = computeDict((Instance) values[8], storage);
     }
     
     private static Instance computeStorage(Instance storage, Instance pythonInstance) {
@@ -100,6 +100,14 @@ class PythonObject extends TruffleObject.InstanceBased {
         return null;
     }
     
+    private static Instance computeDict(Instance dict, Instance storage) {
+        if (dict != null) return dict;
+        if (isSubClassOf(storage, HASHING_STORAGE_FQN)) {
+            return storage;
+        }
+        return null;
+    }
+
     private static Instance computePythonClass(Instance pythonClass, Instance storedPythonClass, Instance initialPythonClass, Instance storage) {
         if (pythonClass != null) return pythonClass;
         if (storedPythonClass != null) return storedPythonClass;
@@ -149,16 +157,16 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     @Override
-    public String getType(Heap heap) {
+    public String getType() {
         if (type == null) {
-            type = pythonClass == null ? null : DetailsUtils.getInstanceString(pythonClass, null);
+            type = pythonClass == null ? null : DetailsUtils.getInstanceString(pythonClass);
             if (type == null) type = "<unknown type>"; // NOI18N
         }
         return type;
     }
 
     @Override
-    public long getTypeId(Heap heap) {
+    public long getTypeId() {
         return pythonClass == null ? Long.MIN_VALUE : pythonClass.getInstanceId();
     }
 
@@ -184,7 +192,7 @@ class PythonObject extends TruffleObject.InstanceBased {
 
     List<FieldValue> getReferences() {
         List<Value> refs = instance.getReferences();
-        List<FieldValue> robjRefs = new ArrayList();
+        List<FieldValue> robjRefs = new ArrayList<>();
 
         for (Value ref : refs) {
             Instance defInstance = ref.getDefiningInstance();
@@ -388,41 +396,43 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     private List<FieldValue> getEntriesFromKeywords(ObjectArrayInstance keywords) {
-        List fields = new ArrayList();
+        List<FieldValue> fields = new ArrayList<>();
 
-        for (Object keyword : keywords.getValues()) {
-            if (keyword instanceof Instance) {
-                fields.add(new PythonKeywordEntryFieldValue(false, (Instance) keyword));
+        for (Instance keyword : keywords.getValues()) {
+            if (keyword != null) {
+                fields.add(new PythonKeywordEntryFieldValue(false, keyword));
             }
         }
         return fields;
     }
 
     private List<FieldValue> getEntriesFromEconomicMapStorage(boolean isSet, Instance economicMapStorage) {
-        List fields = new ArrayList();
-        Instance entries = (Instance) economicMapStorage.getValueOfField("entries"); // NOI18N
+        Instance entries;
+        List<FieldValue> fields = new ArrayList<>();
+        Instance economicMap = (Instance) economicMapStorage.getValueOfField("map"); // NOI18N
+        if (economicMap instanceof Instance) {
+            economicMapStorage = economicMap;
+        }
+        entries = (Instance) economicMapStorage.getValueOfField("entries"); // NOI18N
 
         if (entries instanceof ObjectArrayInstance) {
             ObjectArrayInstance entriesArr = (ObjectArrayInstance) entries;
             String mapClassName = economicMapStorage.getJavaClass().getName();
             int size = entriesArr.getLength();
-            List entriesList = entriesArr.getValues();
+            List<Instance> entriesList = entriesArr.getValues();
 
             for (int i = 0; i < size; i+=2) {
-                Instance key = (Instance) entriesList.get(i);
-                Instance value = (Instance) entriesList.get(i+1);
+                Instance key = entriesList.get(i);
+                Instance value = entriesList.get(i+1);
                 if (key != null) {
                     if (isSet) {
                         fields.add(new PythonEconomicEntryFieldValue(key));
                     } else {    // Map
-                        if (value != null) {
-                            if (value instanceof Instance) {
-                                Instance ival = ((Instance)value);
+                        if (value instanceof Instance) {
+                            Instance ival = ((Instance)value);
+                            if (ival.getJavaClass().getName().startsWith(mapClassName)) {
                                 Instance linkValue = (Instance) ival.getValueOfField("value"); // NOI18N
-
-                                if (linkValue != null && ival.getJavaClass().getName().startsWith(mapClassName)) {
-                                    value = linkValue;
-                                }
+                                if (linkValue != null) value = linkValue;
                             }
                         }
                         fields.add(new PythonEconomicEntryFieldValue(key, value));
@@ -434,7 +444,7 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     private List<FieldValue> getEntriesFromTreeMap(boolean isSet, Instance treeMap) {
-        List fields = new ArrayList();
+        List<FieldValue> fields = new ArrayList<>();
         Instance rootEntry = (Instance) treeMap.getValueOfField("root"); // NOI18N
 
         getEntries(isSet, rootEntry, fields);
@@ -538,7 +548,7 @@ class PythonObject extends TruffleObject.InstanceBased {
                 return new PythonMapEntryField("item"); // NOI18N
             }
             Instance key = getEntryKey();
-            String name = DetailsUtils.getInstanceString(key, null);
+            String name = DetailsUtils.getInstanceString(key);
             return new PythonMapEntryField(name);
         }
 
@@ -637,12 +647,34 @@ class PythonObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return listType;
-                }
-            };
+            return new PFieldType(listType);
+        }
+    }
+
+    private static class PFieldType implements Type {
+
+        private final String name;
+
+        PFieldType(String n) {
+            name = n;
+        }
+
+        @Override
+        public String getName() {
+            return name;
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (obj instanceof PFieldType) {
+                return getName().equals(((PFieldType)obj).getName());
+            }
+            return false;
+        }
+
+        @Override
+        public int hashCode() {
+            return getName().hashCode();
         }
     }
 
