@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,7 +25,6 @@
 
 package org.graalvm.visualvm.heapviewer.truffle.ui;
 
-import org.graalvm.visualvm.heapviewer.truffle.swing.EditableHistoryCombo;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.event.ActionEvent;
@@ -49,23 +48,24 @@ import javax.swing.RowFilter;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.text.JTextComponent;
+import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
+import org.graalvm.visualvm.heapviewer.model.HeapViewerNodeFilter;
+import org.graalvm.visualvm.heapviewer.truffle.TruffleType;
+import org.graalvm.visualvm.heapviewer.truffle.swing.EditableHistoryCombo;
+import org.graalvm.visualvm.heapviewer.ui.TreeTableView;
 import org.graalvm.visualvm.lib.jfluid.filters.GenericFilter;
 import org.graalvm.visualvm.lib.jfluid.filters.TextFilter;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
+import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
+import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
+import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.ui.UIUtils;
 import org.graalvm.visualvm.lib.ui.components.CloseButton;
 import org.graalvm.visualvm.lib.ui.results.ColoredFilter;
 import org.graalvm.visualvm.lib.ui.results.PackageColorer;
 import org.graalvm.visualvm.lib.ui.swing.InvisibleToolbar;
 import org.graalvm.visualvm.lib.ui.swing.PopupButton;
-import org.graalvm.visualvm.lib.profiler.api.ActionsSupport;
-import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
-import org.graalvm.visualvm.heapviewer.model.HeapViewerNodeFilter;
-import org.graalvm.visualvm.heapviewer.truffle.TruffleType;
-import org.graalvm.visualvm.heapviewer.ui.TreeTableView;
-import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
 import org.openide.util.NbBundle;
 
 /**
@@ -75,13 +75,17 @@ import org.openide.util.NbBundle;
 @NbBundle.Messages({
     "TruffleFilterUtils_ActionFilter=Filter",
     "TruffleFilterUtils_TypeFilter=Type Filter:",
+    "# {0} - accelerator",
     "TruffleFilterUtils_FilterResults=Filter results ({0})",
     "TruffleFilterUtils_MatchCase=Match case",
+    "# {0} - accelerator",
     "TruffleFilterUtils_Close=Close Filter sidebar ({0})",
+    "# {0} - invalid text",
     "TruffleFilterUtils_InvalidRegexp=Entered regular expression is invalid:\n{0}",
     "TruffleFilterUtils_FilterContains=Contains",
     "TruffleFilterUtils_FilterNotContains=Does Not Contain",
     "TruffleFilterUtils_FilterRegExp=Regular Expression",
+    "# {0} - name",
     "TruffleFilterUtils_FilterType=Filter type: {0}",
     "TruffleFilterUtils_InsertFilter=Insert Defined Filter"
 })
