@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -42,20 +42,26 @@ public class ThreadNode extends InstanceNode implements CCTNode.DoNotSortChildre
     
     private final String name;
     private final boolean isOOME;
+    private final Thread.State state;
     
     
     public ThreadNode(String name, Instance instance) {
-        this(name, false, instance);
+        this(name, null, false, instance);
+    }
+
+    public ThreadNode(String name, Thread.State state, Instance instance) {
+        this(name, state, false, instance);
     }
     
-    public ThreadNode(String name, boolean isOOME, Instance instance) {
+    public ThreadNode(String name, Thread.State state, boolean isOOME, Instance instance) {
         super(instance);
         this.name = name;
         this.isOOME = isOOME;
+        this.state = state;
     }
     
     
-    public String getName(Heap heap) {
+    public String getName() {
         return name;
     }
     
@@ -63,11 +69,14 @@ public class ThreadNode extends InstanceNode implements CCTNode.DoNotSortChildre
         return isOOME;
     }
     
+    public Thread.State getState() {
+        return state;
+    }
     
     public static class Unknown extends ThreadNode {
         
         public Unknown() {
-            super(Bundle.ThreadNode_UnknownThread(), null);
+            super(Bundle.ThreadNode_UnknownThread(), null, null);
         }
         
         public boolean equals(Object o) {
