@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,17 +25,12 @@
 
 package org.graalvm.visualvm.heapviewer.java.impl;
 
-import org.graalvm.visualvm.heapviewer.HeapContext;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
-import org.openide.DialogDescriptor;
-import org.openide.filesystems.FileObject;
-import org.openide.filesystems.FileUtil;
-import org.openide.util.NbBundle;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.HierarchyEvent;
@@ -45,7 +40,6 @@ import java.awt.event.ItemListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.RandomAccessFile;
 import java.util.ArrayList;
@@ -72,6 +66,7 @@ import javax.swing.event.DocumentListener;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
 import javax.swing.filechooser.FileFilter;
+import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
 import org.graalvm.visualvm.lib.jfluid.utils.StringUtils;
@@ -79,7 +74,11 @@ import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerStorage;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
+import org.openide.filesystems.FileObject;
+import org.openide.filesystems.FileUtil;
+import org.openide.util.NbBundle;
 import org.openide.windows.WindowManager;
 
 /**
@@ -149,7 +148,7 @@ class JavaDiffDumpSelector {
             } else if (fromFileRadio.isSelected()) {
                 String sf = externalFileField.getText();
 
-                if (sf.length() > 0) {
+                if (!sf.isEmpty()) {
                     File s = new File(sf);
 
                     if (s.exists() && s.isFile()) {
@@ -181,9 +180,9 @@ class JavaDiffDumpSelector {
             FileObject[] snapshotsOnDisk = listSavedHeapdumps(heapdumpDir);
             FileObject snapshotFile = (heapdumpFile != null) ? FileUtil.toFileObject(heapdumpFile) : null;
 
-            for (int i = 0; i < snapshotsOnDisk.length; i++) {
-                if (((snapshotFile == null) || !snapshotsOnDisk[i].equals(snapshotFile))) {
-                    listModel.addElement(snapshotsOnDisk[i]);
+            for (FileObject snapshotsOnDisk1 : snapshotsOnDisk) {
+                if ((snapshotFile == null) || !snapshotsOnDisk1.equals(snapshotFile)) {
+                    listModel.addElement(snapshotsOnDisk1);
                 }
             }
 
@@ -475,7 +474,7 @@ class JavaDiffDumpSelector {
                 // Snapshot from file
                 String sf = externalFileField.getText();
 
-                if (sf.length() > 0) {
+                if (!sf.isEmpty()) {
                     // filename not empty string
                     File s = new File(sf);
 
@@ -601,20 +600,16 @@ class JavaDiffDumpSelector {
     private static final String HPROF_HEADER = "JAVA PROFILE 1.0"; // NOI18H
     private static final long MIN_HPROF_SIZE = 1024*1024L;
     static boolean checkHprofFile(File file) {
-        try {
-            if (file.isFile() && file.canRead() && file.length()>MIN_HPROF_SIZE) { // heap dump must be 1M and bigger
-                byte[] prefix = new byte[HPROF_HEADER.length()+4];
-                RandomAccessFile raf = new RandomAccessFile(file,"r");  // NOI18H
+        if (file.isFile() && file.canRead() && file.length()>MIN_HPROF_SIZE) { // heap dump must be 1M and bigger
+            byte[] prefix = new byte[HPROF_HEADER.length()+4];
+            try (RandomAccessFile raf = new RandomAccessFile(file,"r")) {       // NOI18N
                 raf.readFully(prefix);
-                raf.close();
                 if (new String(prefix).startsWith(HPROF_HEADER)) {
                     return true;
                 }
+            } catch (IOException ex) {
+                return false;
             }
-        } catch (FileNotFoundException ex) {
-            return false;
-        } catch (IOException ex) {
-            return false;
         }
         return false;
     }
@@ -639,10 +634,10 @@ class JavaDiffDumpSelector {
 
             ArrayList /*<FileObject>*/ files = new ArrayList /*<FileObject>*/();
 
-            for (int i = 0; i < children.length; i++) {
-                FileObject child = children[i];
-                if (checkHprofFile(FileUtil.toFile(children[i])))
+            for (FileObject child : children) {
+                if (checkHprofFile(FileUtil.toFile(child))) {
                     files.add(child);
+                }
             }
 
             Collections.sort(files,
