@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -607,6 +607,9 @@ class JavaFieldsPlugin extends HeapViewPlugin {
             return getInstance() == null ? 37 : super.hashCode();
         }
         
+        public boolean isLeaf() {
+            return valuesCount == 0;
+        }
         
         abstract String fieldName();
         
@@ -643,6 +646,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
                         protected boolean exclude(Instance instance) {
                             _progress.step();
                             FieldValue value = getValueOfField(instance, fieldName);
+                            if (value == null) return _instance != null;
                             if (!(value instanceof ObjectFieldValue)) return true;
                             return !Objects.equals(_instance, ((ObjectFieldValue)value).getInstance());
                         }
