@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -139,7 +139,7 @@ class JavaObjectsSummary extends HeapView {
     
     
     private void init() {
-        Heap heap = context.getFragment().getHeap();
+        final Heap heap = context.getFragment().getHeap();
         final ClassNodeRenderer classRenderer = new ClassNodeRenderer(heap);
         final InstanceNodeRenderer instanceRenderer = new InstanceNodeRenderer(heap);
         
@@ -329,7 +329,6 @@ class JavaObjectsSummary extends HeapView {
         
         new RequestProcessor("Objects Summary Worker").post(new Runnable() { // NOI18N
             public void run() {
-                Heap heap = context.getFragment().getHeap();
                 List<JavaClass> allClasses = new ArrayList(heap.getAllClasses());
                 
                 // --- Classes by Instances Count ------------------------------
