@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,17 +24,6 @@
  */
 package org.graalvm.visualvm.heapviewer.java.impl;
 
-import org.graalvm.visualvm.core.ui.components.SectionSeparator;
-import org.graalvm.visualvm.heapviewer.HeapContext;
-import org.graalvm.visualvm.heapviewer.java.JavaHeapFragment;
-import org.graalvm.visualvm.heapviewer.swing.LinkButton;
-import org.graalvm.visualvm.heapviewer.swing.Splitter;
-import org.graalvm.visualvm.heapviewer.ui.HeapView;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
-import org.graalvm.visualvm.heapviewer.ui.SummaryView;
-import org.graalvm.visualvm.uisupport.SeparatorLine;
-import org.graalvm.visualvm.uisupport.VerticalLayout;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Dimension;
@@ -53,6 +42,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
+import java.util.SortedSet;
 import java.util.TreeSet;
 import javax.swing.BorderFactory;
 import javax.swing.JComponent;
@@ -67,6 +57,15 @@ import javax.swing.table.TableModel;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Caret;
 import javax.swing.text.JTextComponent;
+import org.graalvm.visualvm.core.ui.components.SectionSeparator;
+import org.graalvm.visualvm.heapviewer.HeapContext;
+import org.graalvm.visualvm.heapviewer.java.JavaHeapFragment;
+import org.graalvm.visualvm.heapviewer.swing.LinkButton;
+import org.graalvm.visualvm.heapviewer.swing.Splitter;
+import org.graalvm.visualvm.heapviewer.ui.HeapView;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
+import org.graalvm.visualvm.heapviewer.ui.SummaryView;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.HeapSummary;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
@@ -78,6 +77,8 @@ import org.graalvm.visualvm.lib.ui.components.HTMLTextArea;
 import org.graalvm.visualvm.lib.ui.components.HTMLTextAreaSearchUtils;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
+import org.graalvm.visualvm.uisupport.SeparatorLine;
+import org.graalvm.visualvm.uisupport.VerticalLayout;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.lookup.ServiceProvider;
@@ -108,6 +109,7 @@ import org.openide.util.lookup.ServiceProvider;
     "JavaOverviewSummary_JvmItemString=Java Name:",
     "JavaOverviewSummary_JavaVendorItemString=Java Vendor:",
     "JavaOverviewSummary_VmArgsSection=JVM Arguments",
+    "JavaOverviewSummary_ModulesSection=Enabled Modules",
     "JavaOverviewSummary_SysPropsSection=System Properties",
     "JavaOverviewSummary_LinkShow=show",
     "JavaOverviewSummary_LinkHide=hide",
@@ -125,6 +127,7 @@ class JavaOverviewSummary extends HeapView {
     private final Object[][] environmentData;
     
     private final String vmArgsData;
+    private final String modulesData;
     private final String syspropsData;
     
     private JComponent component;
@@ -139,6 +142,7 @@ class JavaOverviewSummary extends HeapView {
         heapData = computeHeapData(heap);
         environmentData = computeEnvironmentData(heap, sysprops);
         vmArgsData = computeVMArgs(heap);
+        modulesData = computeModules(heap);
         syspropsData = computeSyspropsData(sysprops);
     }
     
@@ -160,8 +164,10 @@ class JavaOverviewSummary extends HeapView {
         ResultsSnippet environmentSnippet = new ResultsSnippet(Bundle.JavaOverviewSummary_EnvironmentSection(), environmentData, 1);
         Splitter overviewRow = new Splitter(Splitter.HORIZONTAL_SPLIT, heapSnippet, environmentSnippet);
         
-        VMArgsSnippet vmArgsSnippet = vmArgsData == null ? null : new VMArgsSnippet(vmArgsData);
-        SyspropsSnippet syspropsSnippet = new SyspropsSnippet(syspropsData);
+        Snippet modulesSnippet = modulesData == null ? null : new Snippet(Bundle.JavaOverviewSummary_ModulesSection(), modulesData);
+        Snippet vmArgsSnippet = vmArgsData == null ? null : new Snippet(Bundle.JavaOverviewSummary_VmArgsSection(), vmArgsData);
+        Snippet syspropsSnippet = new Snippet(Bundle.JavaOverviewSummary_SysPropsSection(), syspropsData);
+        syspropsSnippet.setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 5));
         
         component = new JPanel(new VerticalLayout(false)) {
             public Dimension getMinimumSize() {
@@ -180,6 +186,7 @@ class JavaOverviewSummary extends HeapView {
         
         component.add(overviewRow);
         if (vmArgsSnippet != null) component.add(vmArgsSnippet);
+        if (modulesSnippet != null) component.add(modulesSnippet);
         component.add(syspropsSnippet);
     }
     
@@ -238,11 +245,16 @@ class JavaOverviewSummary extends HeapView {
 
             String home = sysprops.getProperty("java.home", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
 
+            String name_ver = sysprops.getProperty("java.vm.version", ""); // NOI18N
             String version = sysprops.getProperty("java.version", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
             if ("0".equals(version)) version = Bundle.JavaOverviewSummary_NotAvailable(); // NOI18N
+            else {
+                String relDate = sysprops.getProperty("java.version.date", "");         // NOI18N
+                if (!relDate.isEmpty()) version += " " + relDate;
+                if (name_ver.contains("LTS")) version += " LTS";           // NOI18N
+            }
 
             String name = sysprops.getProperty("java.vm.name", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
-            String name_ver = sysprops.getProperty("java.vm.version", ""); // NOI18N
             String name_info = sysprops.getProperty("java.vm.info", ""); // NOI18N
             if (name_ver.isEmpty() || name_info.isEmpty()) {
                 if (name_ver.isEmpty()) name += " (" + name_info + ")"; // NOI18N
@@ -347,13 +359,28 @@ class JavaOverviewSummary extends HeapView {
         return -1;
     }
     
+    private String computeModules(Heap heap) {
+        JavaClass resolvedModulesClass = heap.getJavaClassByName("java.lang.module.ResolvedModule"); // NOI18N
+        if (resolvedModulesClass != null) {
+            SortedSet<String> resolvedModules = new TreeSet(String.CASE_INSENSITIVE_ORDER);
+            List<Instance> modules = resolvedModulesClass.getInstances();
+
+            for (Instance module : modules) {
+                resolvedModules.add(DetailsSupport.getDetailsString(module));
+            }
+            if (resolvedModules.isEmpty()) return null;
+            return formatModules(resolvedModules);
+        }
+        return null;
+    }
+
     private String computeVMArgs(Heap heap) {
         List<String> vmArgsList = new ArrayList();
         JavaClass vmManagementClass = heap.getJavaClassByName("sun.management.VMManagementImpl"); // NOI18N
 
         if (vmManagementClass != null) {
             if (vmManagementClass.getInstancesCount()>0) {
-                Instance vmManagement = (Instance) vmManagementClass.getInstancesIterator().next();
+                Instance vmManagement = vmManagementClass.getInstancesIterator().next();
                 Object vma = vmManagement.getValueOfField("vmArgs"); // NOI18N
 
                 if (vma instanceof Instance) {
@@ -379,7 +406,7 @@ class JavaOverviewSummary extends HeapView {
                         for (int i = 0; i < length; i++) {
                             Instance arg = elements.get(i);
 
-                            vmArgsList.add(DetailsSupport.getDetailsString(arg, heap));
+                            vmArgsList.add(DetailsSupport.getDetailsString(arg));
                         }
                         
                         return vmArgsList.isEmpty() ? Bundle.JavaOverviewSummary_NoJvmArguments() :
@@ -390,6 +417,28 @@ class JavaOverviewSummary extends HeapView {
         }
         return null;
     }
+
+    private String formatModules(Collection<String> data) {
+        boolean oddRow = false;
+        Color oddRowBackground = UIUtils.getDarker(
+                                 UIUtils.getProfilerResultsBackground());
+        String oddRowBackgroundString =
+               "rgb(" + oddRowBackground.getRed() + "," + //NOI18N
+                        oddRowBackground.getGreen() + "," + //NOI18N
+                        oddRowBackground.getBlue() + ")"; //NOI18N
+        StringBuilder sb = new StringBuilder("<table border='0' cellpadding='2' cellspacing='0' width='100%'>"); // NOI18N
+
+        for (String string : data) {
+            sb.append(oddRow ?
+                "<tr><td style='background-color: " + // NOI18N
+                oddRowBackgroundString + ";'>" : "<tr><td>"); // NOI18N
+            oddRow = !oddRow;
+            sb.append(string.replace(" ", "&nbsp;"));   // NOI18N
+            sb.append("</td></tr>"); // NOI18N
+        }
+        sb.append("</table>"); // NOI18N
+        return expandInvalidXMLChars(sb);
+    }
     
     private final String formatVMArgs(List<String> data) {
         boolean oddRow = false;
@@ -468,7 +517,7 @@ class JavaOverviewSummary extends HeapView {
         long seconds = millis / 1000;
         String sSeconds = ((seconds < 10) ? "0" + seconds : "" + seconds); // NOI18N
 
-        if (sHours.length() == 0) {
+        if (sHours.isEmpty()) {
             return Bundle.JavaOverviewSummary_FORMAT_ms(sMinutes, sSeconds);
         } else {
             return Bundle.JavaOverviewSummary_FORMAT_hms(sHours, sMinutes, sSeconds);
@@ -519,16 +568,16 @@ class JavaOverviewSummary extends HeapView {
         }
         
     }
-    
-    private static class VMArgsSnippet extends JPanel {
+
+    private static class Snippet extends JPanel {
         
-        VMArgsSnippet(final String data) {
+        Snippet(String label, final String data) {
             super(new GridBagLayout());
             
             setOpaque(false);
             setBorder(BorderFactory.createEmptyBorder(0, 5, 15, 5));
             
-            JLabel caption = new JLabel(Bundle.JavaOverviewSummary_VmArgsSection());
+            JLabel caption = new JLabel(label);
             caption.setFont(caption.getFont().deriveFont(Font.BOLD));
             GridBagConstraints c = new GridBagConstraints();
             c.gridx = 0;
@@ -543,12 +592,12 @@ class JavaOverviewSummary extends HeapView {
             add(new JLabel("["), c); // NOI18N
             
             if (data != null) {
-                HTMLTextArea vmArgs = new HTMLTextArea(data);
+                HTMLTextArea htmlArea = new HTMLTextArea(data);
                 
                 final JPanel view = new JPanel(new BorderLayout());
                 view.setOpaque(false);
-                view.add(new HorizontalScroller(vmArgs), BorderLayout.CENTER);
-                view.add(HTMLTextAreaSearchUtils.createSearchPanel(vmArgs), BorderLayout.SOUTH);
+                view.add(new HorizontalScroller(htmlArea), BorderLayout.CENTER);
+                view.add(HTMLTextAreaSearchUtils.createSearchPanel(htmlArea), BorderLayout.SOUTH);
 
                 LinkButton lb = new LinkButton() {
                     {
@@ -619,106 +668,6 @@ class JavaOverviewSummary extends HeapView {
         
     }
     
-    private static class SyspropsSnippet extends JPanel {
-        
-        SyspropsSnippet(final String data) {
-            super(new GridBagLayout());
-            
-            setOpaque(false);
-            setBorder(BorderFactory.createEmptyBorder(0, 5, 0, 5));
-            
-            JLabel caption = new JLabel(Bundle.JavaOverviewSummary_SysPropsSection());
-            caption.setFont(caption.getFont().deriveFont(Font.BOLD));
-            GridBagConstraints c = new GridBagConstraints();
-            c.gridx = 0;
-            c.gridy = 0;
-            c.weighty = 1d;
-            add(caption, c);
-
-            c = new GridBagConstraints();
-            c.gridx = 1;
-            c.gridy = 0;
-            c.insets = new Insets(0, 5, 0, 0);
-            add(new JLabel("["), c); // NOI18N
-            
-            if (data != null) {
-                HTMLTextArea properties = new HTMLTextArea(data);
-                
-                final JPanel view = new JPanel(new BorderLayout());
-                view.setOpaque(false);
-                view.add(new HorizontalScroller(properties), BorderLayout.CENTER);
-                view.add(HTMLTextAreaSearchUtils.createSearchPanel(properties), BorderLayout.SOUTH);
-
-                LinkButton lb = new LinkButton() {
-                    {
-                        clicked(); // sets link text, hides properties table
-                    }
-                    @Override
-                    protected void clicked() {
-                        if (view.isVisible()) {
-                            setText(Bundle.JavaOverviewSummary_LinkShow());
-                            view.setVisible(false);
-                        } else {
-                            setText(Bundle.JavaOverviewSummary_LinkHide());
-                            view.setVisible(true);
-                        }
-                    }
-                };
-                c = new GridBagConstraints();
-                c.gridx = 2;
-                c.gridy = 0;
-                c.insets = new Insets(0, 0, 0, 0);
-                add(lb, c);
-                
-                c = new GridBagConstraints();
-                c.gridx = 0;
-                c.gridy = 1;
-                c.gridwidth = GridBagConstraints.REMAINDER;
-                c.weightx = 1d;
-                c.weighty = 1d;
-                c.anchor = GridBagConstraints.NORTHWEST;
-                c.fill = GridBagConstraints.BOTH;
-                c.insets = new Insets(6, 0, 0, 0);
-                add(view, c);
-            } else {
-                JLabel nal = new JLabel(Bundle.JavaOverviewSummary_NotAvailable());
-                nal.setBorder(new LinkButton().getBorder());
-                c = new GridBagConstraints();
-                c.gridx = 2;
-                c.insets = new Insets(0, 0, 0, 0);
-                add(nal, c);
-            }
-            
-            c = new GridBagConstraints();
-            c.gridx = 3;
-            c.gridy = 0;
-            c.insets = new Insets(0, 0, 0, 0);
-            add(new JLabel("]"), c); // NOI18N
-
-            c = new GridBagConstraints();
-            c.gridx = 4;
-            c.gridy = 0;
-            c.weightx = 1d;
-            c.fill = GridBagConstraints.HORIZONTAL;
-            c.insets = new Insets(1, 4, 0, 0);
-            add(new SeparatorLine(), c);
-        }
-        
-        public Dimension getMinimumSize() {
-            Dimension dim = super.getMinimumSize();
-            dim.width = 0;
-            return dim;
-        }
-        
-        public Dimension getPreferredSize() {
-            Dimension dim = super.getPreferredSize();
-            dim.width = 100;
-            return dim;
-        }
-        
-    }
-    
-    
     private static class HorizontalScroller extends JScrollPane {
         
         HorizontalScroller(JComponent view) {
@@ -757,13 +706,16 @@ class JavaOverviewSummary extends HeapView {
         
         private static void scroll(JScrollBar scroller, MouseWheelEvent event) {
             if (event.getScrollType() == MouseWheelEvent.WHEEL_UNIT_SCROLL) {
-                int direction = event.getUnitsToScroll() < 0 ? -1 : 1;
-                int increment = scroller.getUnitIncrement(direction);
-//                int amount = event.getScrollAmount();
-                int amount = 1;
-                int oldValue = scroller.getValue();
-                int newValue = oldValue + increment * amount * direction;
-                if (oldValue != newValue) scroller.setValue(newValue);
+                int unitsToScroll = event.getUnitsToScroll();
+                if (unitsToScroll != 0) {
+                    int direction = unitsToScroll < 0 ? -1 : 1;
+                    int increment = scroller.getUnitIncrement(direction);
+    //                int amount = event.getScrollAmount();
+                    int amount = 1;
+                    int oldValue = scroller.getValue();
+                    int newValue = oldValue + increment * amount * direction;
+                    if (oldValue != newValue) scroller.setValue(newValue);
+                }
                 event.consume();
             }
         }
