@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -36,6 +36,7 @@ import org.graalvm.visualvm.heapviewer.java.InstanceNode;
 import org.graalvm.visualvm.heapviewer.java.LocalObjectNode;
 import org.graalvm.visualvm.heapviewer.java.StackFrameNode;
 import org.graalvm.visualvm.heapviewer.java.ThreadNode;
+import org.graalvm.visualvm.heapviewer.java.ThreadStateNode;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
 import org.graalvm.visualvm.heapviewer.model.RootNode;
 import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
@@ -69,28 +70,57 @@ class JavaThreadsProvider {
     private static final String LOCAL_VARIABLE = Bundle.JavaThreadsProvider_LocalVariable();
     private static final String JNI_LOCAL = Bundle.JavaThreadsProvider_JniLocal();
 
-    
-    static String getThreadName(Instance instance) {
-        String threadName = getThreadInstanceName(instance);
-        Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
-        Boolean daemon = (Boolean)instance.getValueOfField("daemon"); // NOI18N
-        Integer priority = (Integer)instance.getValueOfField("priority"); // NOI18N
-        Integer threadStatus = (Integer)instance.getValueOfField("threadStatus"); // NOI18N
+    private static class ThreadInfo {
 
-        if (daemon == null) {
-            Instance holder = (Instance)instance.getValueOfField("holder");  // NOI18N
-            if (holder != null) {
-                daemon = (Boolean)holder.getValueOfField("daemon"); // NOI18N
-                priority = (Integer)holder.getValueOfField("priority"); // NOI18N
-                threadStatus = (Integer)holder.getValueOfField("threadStatus"); // NOI18N
+        String threadName;
+        Long threadId;
+        Boolean daemon;
+        Integer priority;
+        Thread.State threadState;
+        String virtualName;
+
+        ThreadInfo(JavaClass vtClass, Instance instance) {
+            if (isVirtualThread(vtClass, instance)) {
+                virtualName = "Virtual Thread "+DetailsSupport.getDetailsString(instance); // NOI18N
+                return;
+            }
+            threadName = getThreadInstanceName(instance);
+            threadId = (Long) instance.getValueOfField("tid");    // NOI18N
+            daemon = (Boolean) instance.getValueOfField("daemon"); // NOI18N
+            priority = (Integer) instance.getValueOfField("priority"); // NOI18N
+            Integer threadStatus = (Integer) instance.getValueOfField("threadStatus"); // NOI18N
+
+            if (daemon == null) {
+                Instance holder = (Instance) instance.getValueOfField("holder");  // NOI18N
+                if (holder != null) {
+                    daemon = (Boolean) holder.getValueOfField("daemon"); // NOI18N
+                    priority = (Integer) holder.getValueOfField("priority"); // NOI18N
+                    threadStatus = (Integer) holder.getValueOfField("threadStatus"); // NOI18N
+                }
+            }
+            if (threadStatus != null) {
+                threadState = toThreadState(threadStatus.intValue());
             }
         }
 
-        String tName = "\"" + threadName + "\"" + (daemon.booleanValue() ? " daemon" : "") + " prio=" + priority; // NOI18N
-        if (threadId != null) tName += " tid=" + threadId; // NOI18N
-        if (threadStatus != null) tName += " " + toThreadState(threadStatus.intValue()); // NOI18N
-        
-        return tName;
+        Thread.State getThreadState() {
+            return threadState;
+        }
+
+        public String toString() {
+            if (virtualName != null) {
+                return virtualName;
+            }
+            String tName = "\"" + threadName + "\"" + (daemon.booleanValue() ? " daemon" : "") + " prio=" + priority; // NOI18N
+            if (threadId != null) tName += " tid=" + threadId; // NOI18N
+            if (threadState != null) tName += " " + threadState; // NOI18N
+
+            return tName;
+        }
+    }
+
+    static String getThreadName(JavaClass vtClass, Instance instance) {
+        return new ThreadInfo(vtClass, instance).toString();
     }
     
     static ThreadObjectGCRoot getOOMEThread(Heap heap) {
@@ -129,11 +159,34 @@ class JavaThreadsProvider {
         return null;
     }
     
+    static HeapViewerNode[] getStateNodes(RootNode root, Heap heap) throws InterruptedException {
+        HeapViewerNode[] stateNodes;
+        HeapViewerNode[] threadsNodes = getThreadsNodes(root, heap);
+        Map<Thread.State,List<HeapViewerNode>> states = new HashMap<>();
+        for (HeapViewerNode n : threadsNodes) {
+            Thread.State s = ((ThreadNode)n).getState();
+            List<HeapViewerNode> nodes = states.get(s);
+            if (nodes == null) {
+                nodes = new ArrayList<>();
+                states.put(s, nodes);
+            }
+            nodes.add(n);
+        }
+        int i = 0;
+        stateNodes = new HeapViewerNode[states.size()];
+        for (Map.Entry<Thread.State, List<HeapViewerNode>> stateEntry : states.entrySet()) {
+            Thread.State state = stateEntry.getKey();
+            ThreadStateNode stateNode = new ThreadStateNode(state, stateEntry.getValue());
+            stateNodes[i++] = stateNode;
+        }
+        return stateNodes;
+    }
         
     static HeapViewerNode[] getThreadsNodes(RootNode rootNode, Heap heap) throws InterruptedException {
         List<HeapViewerNode> threadNodes = new ArrayList();
         
         Collection<GCRoot> roots = heap.getGCRoots();
+        JavaClass vtClass = heap.getJavaClassByName("java.lang.VirtualThread");    // NOI18N
         Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> javaFrameMap = computeJavaFrameMap(roots);
         ThreadObjectGCRoot oome = JavaThreadsProvider.getOOMEThread(heap);
         
@@ -147,10 +200,9 @@ class JavaThreadsProvider {
                     StackTraceElement stack[] = threadRoot.getStackTrace();
                     Map<Integer,List<GCRoot>> localsMap = javaFrameMap.get(threadRoot);
 
-                    String tName = JavaThreadsProvider.getThreadName(threadInstance);
-
+                    ThreadInfo ti = new ThreadInfo(vtClass, threadInstance);
                     final List<HeapViewerNode> stackFrameNodes = new ArrayList();
-                    ThreadNode threadNode = new ThreadNode(tName, threadRoot.equals(oome), threadInstance) {
+                    ThreadNode threadNode = new ThreadNode(ti.toString(), ti.getThreadState(), threadRoot.equals(oome), threadInstance) {
                         protected HeapViewerNode[] computeChildren(RootNode root) {
                             return stackFrameNodes.toArray(HeapViewerNode.NO_NODES);
                         }
@@ -207,6 +259,7 @@ class JavaThreadsProvider {
         Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> javaFrameMap = computeJavaFrameMap(roots);
         ThreadObjectGCRoot oome = JavaThreadsProvider.getOOMEThread(heap);
         JavaClass javaClassClass = heap.getJavaClassByName(Class.class.getName());
+        JavaClass vtClass = heap.getJavaClassByName("java.lang.VirtualThread");    // NOI18N
         // Use this to enable VisualVM color scheme for threads dumps:
         // sw.append("<pre style='color: #cc3300;'>"); // NOI18N
         sb.append("<head><style>span.g {color: #666666;}</style></head>");
@@ -216,7 +269,7 @@ class JavaThreadsProvider {
                 ThreadObjectGCRoot threadRoot = (ThreadObjectGCRoot)root;
                 Instance threadInstance = threadRoot.getInstance();
                 if (threadInstance != null) {
-                    String threadName = JavaThreadsProvider.getThreadName(threadInstance);
+                    String threadName = JavaThreadsProvider.getThreadName(vtClass, threadInstance);
                     StackTraceElement stack[] = threadRoot.getStackTrace();
                     Map<Integer,List<GCRoot>> localsMap = javaFrameMap.get(threadRoot);
                     String style=""; // NOI18N
@@ -300,6 +353,16 @@ class JavaThreadsProvider {
         return DetailsSupport.getDetailsString((Instance)threadName);
     }
     
+    private static boolean isVirtualThread(JavaClass vtClass, Instance threadInstance) {
+        if (vtClass != null) {
+            JavaClass threadClass = threadInstance.getJavaClass();
+            for (;threadClass != null; threadClass = threadClass.getSuperClass()) {
+                if (threadClass.equals(vtClass)) return true;
+            }
+        }
+        return false;
+    }
+
     private static Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> computeJavaFrameMap(Collection<GCRoot> roots) {
         Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> javaFrameMap = new HashMap();
         
