@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -365,7 +365,7 @@ class OQLQueryExecutor {
             queryObjects.add(i);
             hasObjectsResults = true;
             if (sb != null) {
-                sb.append(HeapUtils.instanceToHtml(i, true, engine.getHeap(), null));
+                sb.append(HeapUtils.instanceToHtml(i, true, null));
                 hasHTMLResults = true;
             }
         } else if (o instanceof JavaClass) {
@@ -391,7 +391,7 @@ class OQLQueryExecutor {
                     queryObjects.add(i);
                     hasObjectsResults = true;
                     if (sb != null) {
-                        sb.append(HeapUtils.instanceToHtml(i, true, engine.getHeap(), null));
+                        sb.append(HeapUtils.instanceToHtml(i, true, null));
                         hasHTMLResults = true;
                     }
                 } else if (o instanceof JavaClass) {
