@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -148,7 +148,7 @@ class RecordingViewSupport {
             s.append("</tr>");
             
             s.append("<tr>");
-            s.append("<td><b>Last event time:</b>&nbsp;</td><td>").append(lastEventTime.toString()).append("</td>");
+            s.append("<td><b>Last event time:</b>&nbsp;</td><td>").append(lastEventTime).append("</td>");
             s.append("<td style='padding-left: 50px;'><b>Events time:</b>&nbsp;</td><td>").append(totalTime).append("</td>");
             s.append("</tr>");
             
@@ -263,7 +263,7 @@ class RecordingViewSupport {
             }
 
             @Override
-            public Class getColumnClass(int column) {
+            public Class<?> getColumnClass(int column) {
                 switch (column) {
                     case 0: return JTree.class;
                     case 1: return String.class;
@@ -341,7 +341,7 @@ class RecordingViewSupport {
                 public void run() { model.fireTableDataChanged(); }
             });
             
-            cache = new HashSet();
+            cache = new HashSet<>();
         }
 
         @Override
