@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -27,11 +27,6 @@ package org.graalvm.visualvm.jmx.impl;
 
 import com.sun.management.HotSpotDiagnosticMXBean;
 import com.sun.management.VMOption;
-import org.graalvm.visualvm.application.jvm.HeapHistogram;
-import org.graalvm.visualvm.tools.jmx.JmxModel;
-import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import java.io.IOException;
 import java.lang.management.LockInfo;
 import java.lang.management.ManagementFactory;
@@ -39,8 +34,13 @@ import java.lang.management.MonitorInfo;
 import java.lang.management.RuntimeMXBean;
 import java.lang.management.ThreadInfo;
 import java.lang.management.ThreadMXBean;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.text.SimpleDateFormat;
+import java.util.Collections;
 import java.util.Date;
+import java.util.Map;
 import java.util.Properties;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -52,6 +52,11 @@ import javax.management.MBeanServerConnection;
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 import javax.management.ReflectionException;
+import org.graalvm.visualvm.application.jvm.HeapHistogram;
+import org.graalvm.visualvm.tools.jmx.JmxModel;
+import org.graalvm.visualvm.tools.jmx.JmxModel.ConnectionState;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
 import org.openide.ErrorManager;
 import org.openide.util.Exceptions;
 
@@ -69,6 +74,7 @@ public class JmxSupport {
     private static final String HISTOGRAM_COMMAND = "gcClassHistogram";       // NOI18N
     private static final String CMDLINE_COMMAND = "vmCommandLine";       // NOI18N
     private static final String CMDLINE_PREFIX = "java_command: ";       // NOI18N
+    private static final String CMDLINE_EMPTY = "<unknown>";            // NOI18N
 
     private JvmMXBeans mxbeans;
     private JmxModel jmxModel;
@@ -82,6 +88,9 @@ public class JmxSupport {
     private Boolean hasDumpAllThreads;
     private final Object hasDumpAllThreadsLock = new Object();
     
+    private String commandLine;
+    private final Object commandLineLock = new Object();
+
     JmxSupport(JmxModel jmx) {
         jmxModel = jmx;
     }
@@ -118,7 +127,7 @@ public class JmxSupport {
         }
     }
 
-    synchronized boolean isReadOnlyConnection() {
+    boolean isReadOnlyConnection() {
         synchronized (readOnlyConnectionLock) {
             if (readOnlyConnection == null) {
                 readOnlyConnection = Boolean.FALSE;
@@ -334,6 +343,12 @@ public class JmxSupport {
                 hsDiagnostic.dumpHeap(fileName,true);
             } catch (IOException ex) {
                 LOGGER.log(Level.INFO,"takeHeapDump", ex); // NOI18N
+                try {
+                    Path f = Paths.get(fileName);
+                    Files.deleteIfExists(f);
+                } catch (IOException ex1) {
+                    LOGGER.log(Level.INFO,"takeHeapDump", ex1); // NOI18N
+                }
                 return false;
             }
             return true;
@@ -362,34 +377,10 @@ public class JmxSupport {
     }
 
     HeapHistogram takeHeapHistogram() {
-        if (jmxModel.getConnectionState() == ConnectionState.CONNECTED) {
-            MBeanServerConnection conn = jmxModel.getMBeanServerConnection();
-            try {
-                ObjectName diagCommName = new ObjectName(DIAGNOSTIC_COMMAND_MXBEAN_NAME);
-
-                if (conn.isRegistered(diagCommName)) {
-                    Object histo = conn.invoke(diagCommName,
-                                HISTOGRAM_COMMAND,
-                                new Object[] {new String[] {ALL_OBJECTS_OPTION}},
-                                new String[] {String[].class.getName()}
-                    );
-                    if (histo instanceof String) {
-                        return new HeapHistogramImpl((String)histo);
-                    }
-                }
-            } catch (MalformedObjectNameException ex) {
-                Exceptions.printStackTrace(ex);
-            } catch (IOException ex) {
-                LOGGER.log(Level.INFO,"takeHeapHistogram", ex); // NOI18N
-            } catch (InstanceNotFoundException ex) {
-                Exceptions.printStackTrace(ex);
-            } catch (MBeanException ex) {
-                Exceptions.printStackTrace(ex);
-            } catch (ReflectionException ex) {
-                Exceptions.printStackTrace(ex);
-            } catch (Exception ex) {
-                LOGGER.log(Level.INFO,"takeHeapHistogram", ex); // NOI18N
-            }
+        if (isReadOnlyConnection()) return null;
+        String histo = executeJCmd(HISTOGRAM_COMMAND, Collections.singletonMap(ALL_OBJECTS_OPTION, null));
+        if (histo != null) {
+            return new HeapHistogramImpl(histo);
         }
         return null;
     }
@@ -428,25 +419,44 @@ public class JmxSupport {
     }
 
     String getCommandLine() {
+        synchronized (commandLineLock) {
+            if (commandLine == null) {
+                String vmCommandLine = executeJCmd(CMDLINE_COMMAND);
+                if (vmCommandLine != null) {
+                    commandLine = parseVMCommandLine(vmCommandLine);
+                }
+            }
+            return commandLine;
+        }
+    }
+
+    private String executeJCmd(String command) {
+        return executeJCmd(command, Collections.emptyMap());
+    }
+
+    String executeJCmd(String command, Map<String,Object> pars) {
         if (jmxModel.getConnectionState() == ConnectionState.CONNECTED) {
             MBeanServerConnection conn = jmxModel.getMBeanServerConnection();
             try {
                 ObjectName diagCommName = new ObjectName(DIAGNOSTIC_COMMAND_MXBEAN_NAME);
-
                 if (conn.isRegistered(diagCommName)) {
-                    Object vmCommandLine = conn.invoke(diagCommName,
-                                CMDLINE_COMMAND,
-                                new Object[] {},
-                                new String[] {}
-                    );
-                    if (vmCommandLine instanceof String) {
-                        return parseVMCommandLine((String) vmCommandLine);
+                    Object[] params = null;
+                    String[] signature = null;
+                    Object ret;
+
+                    if (!pars.isEmpty()) {
+                        params = new Object[] {getJCmdParams(pars)};
+                        signature = new String[] {String[].class.getName()};
+                    }
+                    ret = conn.invoke(diagCommName, command, params, signature);
+                    if (ret instanceof String) {
+                        return (String)ret;
                     }
                 }
             } catch (MalformedObjectNameException ex) {
                 Exceptions.printStackTrace(ex);
             } catch (IOException ex) {
-                LOGGER.log(Level.INFO,"getCommandLine", ex); // NOI18N
+                LOGGER.log(Level.INFO,"executeJCmd", ex); // NOI18N
             } catch (InstanceNotFoundException ex) {
                 Exceptions.printStackTrace(ex);
             } catch (MBeanException ex) {
@@ -462,9 +472,37 @@ public class JmxSupport {
       String[] lines = vmCommandLine.split("\\r?\\n");
       for (String line : lines) {
           if (line.startsWith(CMDLINE_PREFIX)) {
-              return line.substring(CMDLINE_PREFIX.length());
+              String cmdline = line.substring(CMDLINE_PREFIX.length());
+              if (CMDLINE_EMPTY.equals(cmdline)) return "";
+              return cmdline;
           }
       }
       return null;
     }
+
+    private static String[] getJCmdParams(Map<String, Object> pars) {
+        String[] jcmdParams = new String[pars.size()];
+        int i = 0;
+        for (Map.Entry<String,Object> e : pars.entrySet()) {
+            String par;
+            String key = e.getKey();
+            Object val = e.getValue();
+
+            if (val == null) {
+                par = key;
+            } else {
+                par = String.format("%s=%s", key, quoteString(val.toString())); // NOI18N
+            }
+            jcmdParams[i++] = par;
+        }
+        return jcmdParams;
+    }
+
+    private static String quoteString(String val) {
+        if (val.indexOf(' ')>=0) {
+            return "\""+val+"\"";   //NOI18N
+        }
+        return val;
+    }
+
 }
