@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,16 +25,16 @@
 
 package org.graalvm.visualvm.lib.common.integration;
 
-import org.graalvm.visualvm.lib.jfluid.ProfilerLogger;
-import org.graalvm.visualvm.lib.common.Profiler;
-import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
-import org.graalvm.visualvm.lib.jfluid.global.Platform;
 import java.io.*;
 import java.nio.channels.FileChannel;
 import java.text.MessageFormat;
 import java.util.ResourceBundle;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import org.graalvm.visualvm.lib.common.Profiler;
+import org.graalvm.visualvm.lib.jfluid.ProfilerLogger;
+import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
+import org.graalvm.visualvm.lib.jfluid.global.Platform;
 
 
 /**
@@ -65,6 +65,9 @@ public class IntegrationUtils {
     public static final String PLATFORM_JAVA_180 = messages.getString("IntegrationUtils_PlatformJava180"); // NOI18N
     public static final String PLATFORM_JAVA_190 = messages.getString("IntegrationUtils_PlatformJava190"); // NOI18N
     public static final String PLATFORM_JAVA_200 = messages.getString("IntegrationUtils_PlatformJava200"); // NOI18N
+    public static final String PLATFORM_JAVA_210 = messages.getString("IntegrationUtils_PlatformJava210"); // NOI18N
+    public static final String PLATFORM_JAVA_220 = messages.getString("IntegrationUtils_PlatformJava220"); // NOI18N
+    public static final String PLATFORM_JAVA_230 = messages.getString("IntegrationUtils_PlatformJava230"); // NOI18N
     public static final String PLATFORM_JAVA_CVM = messages.getString("IntegrationUtils_PlatformJavaCvm"); // NOI18N
     public static final String PLATFORM_WINDOWS_OS = messages.getString("IntegrationUtils_PlatformWindowsOs"); // NOI18N
     public static final String PLATFORM_WINDOWS_AMD64_OS = messages.getString("IntegrationUtils_PlatformWindowsAmd64Os"); // NOI18N
@@ -103,6 +106,9 @@ public class IntegrationUtils {
     private static final String JDK_180_NAME = messages.getString("IntegrationUtils_Jdk180Name"); // NOI18N
     private static final String JDK_190_NAME = messages.getString("IntegrationUtils_Jdk190Name"); // NOI18N
     private static final String JDK_200_NAME = messages.getString("IntegrationUtils_Jdk200Name"); // NOI18N
+    private static final String JDK_210_NAME = messages.getString("IntegrationUtils_Jdk210Name"); // NOI18N
+    private static final String JDK_220_NAME = messages.getString("IntegrationUtils_Jdk220Name"); // NOI18N
+    private static final String JDK_230_NAME = messages.getString("IntegrationUtils_Jdk230Name"); // NOI18N
     private static final String JDK_CVM_NAME = messages.getString("IntegrationUtils_JdkCvmName"); // NOI18N
     private static final String HTML_REMOTE_STRING = "&lt;" + messages.getString("IntegrationUtils_RemoteString") + "&gt;"; // NOI18N
     private static final String EXPORT_SETENV_MESSAGE = messages.getString("IntegrationUtils_ExportSetenvMessage"); // NOI18N
@@ -296,6 +302,12 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_190;
         } else if (javaVersionString.equals(CommonConstants.JDK_200_STRING)) {
             return PLATFORM_JAVA_200;
+        } else if (javaVersionString.equals(CommonConstants.JDK_210_STRING)) {
+            return PLATFORM_JAVA_210;
+        } else if (javaVersionString.equals(CommonConstants.JDK_220_STRING)) {
+            return PLATFORM_JAVA_220;
+        } else if (javaVersionString.equals(CommonConstants.JDK_230_STRING)) {
+            return PLATFORM_JAVA_230;
         } else if (javaVersionString.equals(CommonConstants.JDK_CVM_STRING)) {
             return PLATFORM_JAVA_CVM;
         }
@@ -381,6 +393,12 @@ public class IntegrationUtils {
             return JDK_190_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_200)) {
             return JDK_200_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_210)) {
+            return JDK_210_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_220)) {
+            return JDK_220_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_230)) {
+            return JDK_230_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return JDK_CVM_NAME;
         }
@@ -422,6 +440,12 @@ public class IntegrationUtils {
             return "jdk16"; //NOI18N // for JDK 19 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_200)) {
             return "jdk16"; //NOI18N // for JDK 20 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_210)) {
+            return "jdk16"; //NOI18N // for JDK 21 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_220)) {
+            return "jdk16"; //NOI18N // for JDK 22 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_230)) {
+            return "jdk16"; //NOI18N // for JDK 23 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return "cvm";  // NOI18N
         }
@@ -486,6 +510,12 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_190;
         } else if (jdkVersion == Platform.JDK_200) {
             return PLATFORM_JAVA_200;
+        } else if (jdkVersion == Platform.JDK_210) {
+            return PLATFORM_JAVA_210;
+        } else if (jdkVersion == Platform.JDK_220) {
+            return PLATFORM_JAVA_220;
+        } else if (jdkVersion == Platform.JDK_230) {
+            return PLATFORM_JAVA_230;
         }
 
         return null;
