@@ -34,6 +34,7 @@ import java.io.IOException;
 import java.io.RandomAccessFile;
 import java.nio.MappedByteBuffer;
 import java.nio.channels.FileChannel;
+import static java.nio.channels.FileChannel.MapMode.*;
 
 /**
  * @author Tomas Hurka
@@ -205,6 +206,18 @@ abstract class AbstractLongMap {
         return osName.endsWith("Linux"); // NOI18N
     }
 
+    private static boolean isMacOS() {
+        String osName = System.getProperty("os.name");  // NOI18N
+
+        return "Mac OS X".equals(osName); // NOI18N
+    }
+
+    private static boolean isAarch64() {
+        String osArch = System.getProperty("os.arch");  // NOI18N
+
+        return "aarch64".equals(osArch); // NOI18N
+    }
+
     abstract Entry createEntry(long index);
     
     abstract Entry createEntry(long index,long value);
@@ -379,7 +392,7 @@ abstract class AbstractLongMap {
     
     private static class MemoryMappedData extends AbstractData {
         
-        private static final FileChannel.MapMode MAP_MODE = isLinux() ? FileChannel.MapMode.PRIVATE : FileChannel.MapMode.READ_WRITE;
+        private static final FileChannel.MapMode MAP_MODE = computeMapMode();
 
         //~ Instance fields ------------------------------------------------------------------------------------------------------
 
@@ -421,7 +434,7 @@ abstract class AbstractLongMap {
 
         @Override
         public void force() throws IOException {
-            if (MAP_MODE == FileChannel.MapMode.PRIVATE) {
+            if (MAP_MODE == PRIVATE) {
                 File newBufferFile = new File(bufferFile.getAbsolutePath()+".new"); // NOI18N
                 int length = buf.capacity();
                 new FileOutputStream(newBufferFile).getChannel().write(buf);
@@ -439,6 +452,17 @@ abstract class AbstractLongMap {
                 return channel.map(MAP_MODE, 0, length);
             }
         }
+
+        private static FileChannel.MapMode computeMapMode() {
+            String mode = System.getProperty("org.graalvm.visualvm.lib.jfluid.heap.mapmode");   // NOI18N
+            if (mode != null) {
+                if ("private".equals(mode)) return PRIVATE;     // NOI18N
+                return READ_WRITE;
+            }
+            if (isLinux()) return PRIVATE;
+            if (isMacOS() && isAarch64()) return PRIVATE;
+            return READ_WRITE;
+        }
     }
 
     private static class LongMemoryMappedData extends AbstractData {
@@ -499,7 +523,7 @@ abstract class AbstractLongMap {
 
         @Override
         public void force() throws IOException{
-            if (MemoryMappedData.MAP_MODE == FileChannel.MapMode.PRIVATE) {
+            if (MemoryMappedData.MAP_MODE == PRIVATE) {
                 File newBufferFile = new File(bufferFile.getAbsolutePath()+".new"); // NOI18N
                 long length = bufferFile.length();
                 try (FileChannel channel = new FileOutputStream(newBufferFile).getChannel()) {
