@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2014 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.ui.cpu;
@@ -54,15 +36,19 @@ import javax.swing.Box;
 import javax.swing.JCheckBoxMenuItem;
 import javax.swing.JLabel;
 import javax.swing.JPopupMenu;
+import javax.swing.JToggleButton;
 import javax.swing.JTree;
 import javax.swing.RowFilter;
 import javax.swing.SortOrder;
+import javax.swing.SwingUtilities;
 import javax.swing.tree.TreeNode;
 import javax.swing.tree.TreePath;
 import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
 import org.graalvm.visualvm.lib.jfluid.results.CCTNode;
 import org.graalvm.visualvm.lib.jfluid.results.cpu.CPUResultsSnapshot;
 import org.graalvm.visualvm.lib.jfluid.results.cpu.PrestimeCPUCCTNode;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.swing.ExportUtils;
 import org.graalvm.visualvm.lib.ui.swing.PopupButton;
 import org.graalvm.visualvm.lib.ui.swing.ProfilerTable;
@@ -75,18 +61,16 @@ import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.McsTimeRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberPercentRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberRenderer;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 
 /**
  *
  * @author Jiri Sedlacek
  */
 abstract class CPUTreeTableView extends CPUView {
-    
+
     private CPUTreeTableModel treeTableModel;
     private ProfilerTreeTable treeTable;
-    
+
     private Map<Integer, ClientUtils.SourceCodeSelection> idMap;
     private final Set<ClientUtils.SourceCodeSelection> selection;
     
@@ -104,7 +88,7 @@ abstract class CPUTreeTableView extends CPUView {
     private boolean searchCallerMethods = false;
     
     
-    public CPUTreeTableView(Set<ClientUtils.SourceCodeSelection> selection, boolean reverse) {
+    CPUTreeTableView(Set<ClientUtils.SourceCodeSelection> selection, boolean reverse) {
         this.selection = selection;
         this.reverse = reverse;
         
@@ -343,34 +327,64 @@ abstract class CPUTreeTableView extends CPUView {
     }
     
     protected Component[] getFilterOptions() {
-        if (!reverse) return super.getFilterOptions();
-        
-        PopupButton pb = new PopupButton (Icons.getIcon(ProfilerIcons.TAB_CALL_TREE)) {
-            protected void populatePopup(JPopupMenu popup) {
-                popup.add(new JCheckBoxMenuItem(FILTER_CALLEES_SCOPE, filterTopMethods) {
-                    {
-                        if (!filterCallerMethods) setEnabled(false);
-                    }
-                    protected void fireActionPerformed(ActionEvent e) {
-                        super.fireActionPerformed(e);
-                        filterTopMethods = !filterTopMethods;
-                        enableFilter();
-                    }
-                });
-                popup.add(new JCheckBoxMenuItem(FILTER_CALLERS_SCOPE, filterCallerMethods) {
-                    {
-                        if (!filterTopMethods) setEnabled(false);
-                    }
-                    protected void fireActionPerformed(ActionEvent e) {
-                        super.fireActionPerformed(e);
-                        filterCallerMethods = !filterCallerMethods;
-                        enableFilter();
-                    }
-                });
+        if (reverse) {
+            PopupButton pb = new PopupButton (Icons.getIcon(ProfilerIcons.TAB_CALL_TREE)) {
+                protected void populatePopup(JPopupMenu popup) {
+                    popup.add(new JCheckBoxMenuItem(FILTER_CALLEES_SCOPE, filterTopMethods) {
+                        {
+                            if (!filterCallerMethods) setEnabled(false);
+                        }
+                        protected void fireActionPerformed(ActionEvent e) {
+                            super.fireActionPerformed(e);
+                            filterTopMethods = !filterTopMethods;
+                            enableFilter();
+                        }
+                    });
+                    popup.add(new JCheckBoxMenuItem(FILTER_CALLERS_SCOPE, filterCallerMethods) {
+                        {
+                            if (!filterTopMethods) setEnabled(false);
+                        }
+                        protected void fireActionPerformed(ActionEvent e) {
+                            super.fireActionPerformed(e);
+                            filterCallerMethods = !filterCallerMethods;
+                            enableFilter();
+                        }
+                    });
+                }
+            };
+            pb.setToolTipText(FILTER_SCOPE_TOOLTIP);
+            return new Component[] { Box.createHorizontalStrut(5), pb };
+        } else {
+            final RowFilter zeroFilter = new RowFilterImpl();
+            final JToggleButton zeroSelfTime = new JToggleButton(Icons.getIcon(ProfilerIcons.NODE_LEAF)) {
+
+                protected void fireActionPerformed(ActionEvent e) {
+                    super.fireActionPerformed(e);
+                    boolean selected = isSelected();
+
+                    SwingUtilities.invokeLater(() -> {
+                        if (selected) {
+                            treeTable.addRowFilter(zeroFilter);
+                        } else {
+                            treeTable.removeRowFilter(zeroFilter);
+                        }
+                    });
+                }
+            };
+            zeroSelfTime.setToolTipText(HIDE_ZERO_SELF_TIME_TOOLTIP);
+            return new Component[]{Box.createHorizontalStrut(5), zeroSelfTime};
+        }
+    }
+
+    private static class RowFilterImpl extends RowFilter implements ProfilerTreeTable.DeleteNodes {
+
+        public boolean include(RowFilter.Entry entry) {
+            PrestimeCPUCCTNode node = (PrestimeCPUCCTNode) entry.getIdentifier();
+            if (node.isSelfTimeNode() && node.getTotalTime0() == 0) {
+                return false;
             }
-        };
-        pb.setToolTipText(FILTER_SCOPE_TOOLTIP);
-        return new Component[] { Box.createHorizontalStrut(5), pb };
+            return true;
+        }
     }
     
     protected SearchUtils.TreeHelper getSearchHelper() {
