@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -522,30 +522,31 @@ public class ReverseCallGraphPanel extends SnapshotCPUResultsPanel implements Sc
             });
 
         treeTable.addMouseListener(new MouseAdapter() {
-                public void mousePressed(MouseEvent e) {
-                    if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                        popupPath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
-
-                        if (popupPath != null) {
-                            treeTable.getTree().setSelectionPath(popupPath);
-                        }
+                private void showPopupMenu(MouseEvent e) {
+                    popupPath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
+                    if (popupPath == null) {
+                            treeTable.getTree().clearSelection();
+                    } else {
+                        treeTable.getTree().setSelectionPath(popupPath);
+                        PrestimeCPUCCTNode node = (PrestimeCPUCCTNode) popupPath.getLastPathComponent();
+                        enableDisablePopup(node);
+                        callGraphPopupMenu.show(e.getComponent(), e.getX(), e.getY());
                     }
                 }
+                public void mousePressed(MouseEvent e) {
+                    if (e.isPopupTrigger()) showPopupMenu(e);
+                }
+
+                public void mouseReleased(MouseEvent e) {
+                    if (e.isPopupTrigger()) showPopupMenu(e);
+                }
 
                 public void mouseClicked(MouseEvent e) {
                     popupPath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
 
-                    if (popupPath == null) {
-                        if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                            treeTable.getTree().clearSelection();
-                        }
-                    } else {
+                    if (popupPath != null) {
                         treeTable.getTree().setSelectionPath(popupPath);
-                        if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                            PrestimeCPUCCTNode node = (PrestimeCPUCCTNode) popupPath.getLastPathComponent();
-                            enableDisablePopup(node);
-                            callGraphPopupMenu.show(e.getComponent(), e.getX(), e.getY());
-                        } else if ((e.getModifiers() == InputEvent.BUTTON1_MASK) && (e.getClickCount() == 2)) {
+                        if (SwingUtilities.isLeftMouseButton(e) && (e.getClickCount() == 2)) {
                             if (treeTableModel.isLeaf(popupPath.getPath()[popupPath.getPath().length - 1])) {
                                 showSourceForMethod(popupPath);
                             }
