@@ -1,53 +1,30 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.ui.cpu;
 
-import org.graalvm.visualvm.lib.ui.charts.ChartModelListener;
-import org.graalvm.visualvm.lib.ui.charts.PieChart;
-import org.graalvm.visualvm.lib.ui.charts.PieChartModel;
-import org.graalvm.visualvm.lib.ui.components.HTMLTextArea;
-import org.graalvm.visualvm.lib.ui.components.SnippetPanel;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
@@ -82,6 +59,11 @@ import javax.swing.Scrollable;
 import javax.swing.SwingConstants;
 import javax.swing.UIManager;
 import org.graalvm.visualvm.lib.ui.UIUtils;
+import org.graalvm.visualvm.lib.ui.charts.ChartModelListener;
+import org.graalvm.visualvm.lib.ui.charts.PieChart;
+import org.graalvm.visualvm.lib.ui.charts.PieChartModel;
+import org.graalvm.visualvm.lib.ui.components.HTMLTextArea;
+import org.graalvm.visualvm.lib.ui.components.SnippetPanel;
 
 
 /**
@@ -111,7 +93,7 @@ public class StatisticsPanel extends JPanel {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public ChartItemPresenter(PieChart pieChart, int index) {
+        ChartItemPresenter(PieChart pieChart, int index) {
             this.model = pieChart.getModel();
             this.index = index;
 
@@ -164,7 +146,7 @@ public class StatisticsPanel extends JPanel {
     private class ChartPanel extends JPanel {
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public ChartPanel(PieChart pieChart) {
+        ChartPanel(PieChart pieChart) {
             initComponents(pieChart);
         }
 
@@ -226,11 +208,11 @@ public class StatisticsPanel extends JPanel {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public ColorIcon(Color color) {
+        ColorIcon(Color color) {
             this(ICON_SIZE, ICON_SIZE, color);
         }
 
-        public ColorIcon(int width, int height, Color color) {
+        ColorIcon(int width, int height, Color color) {
             this.width = width;
             this.height = height;
             setColor(color);
@@ -265,7 +247,7 @@ public class StatisticsPanel extends JPanel {
     private static class Container extends JPanel implements Scrollable {
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public Container() {
+        Container() {
             setLayout(new BorderLayout());
             setOpaque(true);
             setBackground(UIUtils.getProfilerResultsBackground());
@@ -302,7 +284,7 @@ public class StatisticsPanel extends JPanel {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public KeyboardAwareLabel(final boolean selectable, final Runnable actionPerformer) {
+        KeyboardAwareLabel(final boolean selectable, final Runnable actionPerformer) {
             super();
 
             setOpaque(false);
@@ -387,7 +369,7 @@ public class StatisticsPanel extends JPanel {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public NavPanel(HTMLTextArea navArea) {
+        NavPanel(HTMLTextArea navArea) {
             initColors();
             initComponents(navArea);
         }
@@ -494,7 +476,7 @@ public class StatisticsPanel extends JPanel {
     private NavPanel navPanel;
     private PieChart pieChart;
     private Runnable navigationBackPerformer;
-    private Collection<Listener> listeners = new CopyOnWriteArraySet<Listener>();
+    private Collection<Listener> listeners = new CopyOnWriteArraySet<>();
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
@@ -677,7 +659,7 @@ public class StatisticsPanel extends JPanel {
             container.add((JComponent) snippets.get(i), constraints);
         }
 
-        if (snippets.size() == 0) {
+        if (snippets.isEmpty()) {
             constraints = new GridBagConstraints();
             constraints.gridx = 0;
             constraints.gridy = 2 + itemPresenters.size() + 1;
