@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -284,28 +284,30 @@ public class LiveReverseMemCallGraphPanel extends ReverseMemCallGraphPanel {
             UIUtils.makeTreeAutoExpandable(treeTable.getTree());
 
             treeTable.addMouseListener(new MouseAdapter() {
-                    public void mousePressed(MouseEvent e) {
-                        if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                            treePath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
+                    private void showPopupMenu(MouseEvent e) {
+                        treePath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
 
-                            if (treePath != null) {
-                                treeTable.getTree().setSelectionPath(treePath);
-                            }
+                        if (treePath == null) {
+                                treeTable.getTree().clearSelection();
+                        } else {
+                            treeTable.getTree().setSelectionPath(treePath);
+                            popupMenu.show(e.getComponent(), e.getX(), e.getY());
                         }
                     }
+                    public void mousePressed(MouseEvent e) {
+                        if (e.isPopupTrigger()) showPopupMenu(e);
+                    }
+
+                    public void mouseReleased(MouseEvent e) {
+                        if (e.isPopupTrigger()) showPopupMenu(e);
+                    }
 
                     public void mouseClicked(MouseEvent e) {
                         treePath = treeTable.getTree().getPathForRow(treeTable.rowAtPoint(e.getPoint()));
 
-                        if (treePath == null) {
-                            if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                                treeTable.getTree().clearSelection();
-                            }
-                        } else {
+                        if (treePath != null) {
                             treeTable.getTree().setSelectionPath(treePath);
-                            if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                                popupMenu.show(e.getComponent(), e.getX(), e.getY());
-                            } else if ((e.getModifiers() == InputEvent.BUTTON1_MASK) && (e.getClickCount() == 2)) {
+                            if (SwingUtilities.isLeftMouseButton(e) && (e.getClickCount() == 2)) {
                                 if (treeTableModel.isLeaf(treePath.getPath()[treePath.getPath().length - 1])) {
                                     performDefaultAction(treePath);
                                 }
