@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -301,6 +301,12 @@ public class Platform implements CommonConstants {
             jdkVersion = JDK_190;
         } else if (isJavaVersion(javaVersion,"20")) { // NOI18N
             jdkVersion = JDK_200;
+        } else if (isJavaVersion(javaVersion,"21")) { // NOI18N
+            jdkVersion = JDK_210;
+        } else if (isJavaVersion(javaVersion,"22")) { // NOI18N
+            jdkVersion = JDK_220;
+        } else if (isJavaVersion(javaVersion,"23")) { // NOI18N
+            jdkVersion = JDK_230;
         } else if (javaVersion.equals("CVM")) { // NOI18N
             jdkVersion = JDK_CVM;
         } else {
@@ -352,6 +358,9 @@ public class Platform implements CommonConstants {
             case JDK_180: return JDK_180_STRING;
             case JDK_190: return JDK_190_STRING;
             case JDK_200: return JDK_200_STRING;
+            case JDK_210: return JDK_210_STRING;
+            case JDK_220: return JDK_220_STRING;
+            case JDK_230: return JDK_230_STRING;
             case JDK_CVM: return JDK_CVM_STRING;
             case JDK_UNSUPPORTED: return JDK_UNSUPPORTED_STRING;
         }
