@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -219,11 +219,17 @@ public abstract class MonitorTestCase extends CommonProfilerTestCase {
 
             for (int i = 0; i < threadsManager.getThreadsCount(); i++) {
                 ThreadData td = threadsManager.getThreadData(i);
+                String tname = td.getName();
+                String className = td.getClassName();
 
-                if (!td.getName().equals("process reaper") && !td.getName().equals("DestroyJavaVM")) { //disable system threads
+                if (!tname.startsWith("process reaper") // JDK-8284165
+                 && !tname.equals("DestroyJavaVM")
+                 && !tname.equals("Common-Cleaner")
+                 && !tname.equals("Notification Thread")                            // disable system threads
+                 && !"java.util.logging.LogManager$Cleaner".equals(className)) {    // disable shutdown hook
 
                     byte[] states = new byte[statesNumber];
-                    String n = td.getName() + ", class: " + td.getClassName();
+                    String n = tname + ", class: " + className;
                     byte state = ST_UNKNOWN;
                     long time = threadsManager.getStartTime();
                     int tdindex = 0;
@@ -244,7 +250,7 @@ public abstract class MonitorTestCase extends CommonProfilerTestCase {
 
                     td.clearStates();
                     assertTrue("Error in threadData.clearStates", (td.size() == 0));
-                    names.add(td.getName());
+                    names.add(tname);
                     threads.put(n, states);
                     timestamps.put(n, new Long(td.getFirstTimeStamp()));
                 }
