@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -41,7 +41,6 @@ import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
 import org.graalvm.visualvm.lib.jfluid.results.CCTNode;
-import sun.management.ThreadInfoCompositeData;
 import static org.junit.Assert.*;
 
 
@@ -164,7 +163,7 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotOneSample() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : one sample");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
         assertEquals(instance.methodInfos.size(), snapshot.nInstrMethods);
@@ -174,8 +173,8 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotNoChanges() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : two samples");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 500000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -186,8 +185,8 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotMinus() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : minus");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stackMinus, 500000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stackMinus, 500000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -198,8 +197,8 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotPlus() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : plus");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stackPlus, 500000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stackPlus, 500000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -210,9 +209,9 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotPlusMinus() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : plus->minus");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stackPlus, 500000);
-        addStacktrace(stackMinus, 1000000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stackPlus, 500000);
+        instance.addStacktrace(stackMinus, 1000000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -223,9 +222,9 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotMinusPlus() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : minus->plus");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stackMinus, 500000);
-        addStacktrace(stackPlus, 1000000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stackMinus, 500000);
+        instance.addStacktrace(stackPlus, 1000000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -236,8 +235,8 @@ public class StackTraceSnapshotBuilderTest {
     public void testCreateSnapshotDup() throws CPUResultsSnapshot.NoDataAvailableException {
         System.out.println("create snapshot : dup");
 
-        addStacktrace(stack0, 0);
-        addStacktrace(stackDup, 500000);
+        instance.addStacktrace(stack0, 0);
+        instance.addStacktrace(stackDup, 500000);
 
         CPUResultsSnapshot snapshot = instance.createSnapshot(System.currentTimeMillis());
         assertTrue(snapshot.collectingTwoTimeStamps);
@@ -273,7 +272,7 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktrace() {
         System.out.println("add stacktrace");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         assertTrue(instance.methodInfos.size()-1  == elements0.length);
         assertTrue(instance.threadIds.size() == stack0.length);
         assertTrue(instance.threadNames.size() == stack0.length);
@@ -285,13 +284,13 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : duplicate");
 
         long stamp = 0;
-        addStacktrace(stack0, stamp);
+        instance.addStacktrace(stack0, stamp);
 
         int miSize = instance.methodInfos.size()-1;
         int tIdSize = instance.threadIds.size();
         long timestamp = instance.currentDumpTimeStamp;
 
-        addStacktrace(stack0, stamp);
+        instance.addStacktrace(stack0, stamp);
         assertTrue(instance.stackTraceCount == 1);
 
     }
@@ -300,11 +299,11 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktracePlus() {
         System.out.println("add stacktrace : plus");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
 
-        addStacktrace(stackPlus, timestamp);
+        instance.addStacktrace(stackPlus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackPlus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsPlus.length), instance.methodInfos.size()-1);
@@ -315,12 +314,12 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktracePlusWaiting() {
         System.out.println("add stacktrace : plus/waiting");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackPlus[0],Thread.State.WAITING);
 
-        addStacktrace(stackPlus, timestamp);
+        instance.addStacktrace(stackPlus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackPlus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsPlus.length), instance.methodInfos.size()-1);
@@ -331,12 +330,12 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktracePlusWaitingThread() {
         System.out.println("add stacktrace : plus/waiting; additional thread");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackPlus[2],Thread.State.WAITING);
 
-        addStacktrace(stackPlus, timestamp);
+        instance.addStacktrace(stackPlus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackPlus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsPlus.length), instance.methodInfos.size()-1);
@@ -348,12 +347,12 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : waiting/plus");
 
         setState(stack0[0],Thread.State.WAITING);
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackPlus[2],Thread.State.RUNNABLE);
 
-        addStacktrace(stackPlus, timestamp);
+        instance.addStacktrace(stackPlus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackPlus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsPlus.length), instance.methodInfos.size()-1);
@@ -364,11 +363,11 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceMinus() {
         System.out.println("add stacktrace : minus");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
 
-        addStacktrace(stackMinus, timestamp);
+        instance.addStacktrace(stackMinus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackMinus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsMinus.length), instance.methodInfos.size()-1);
@@ -379,11 +378,11 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceMinusWaiting() {
         System.out.println("add stacktrace : minus/waiting");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackMinus[0], Thread.State.WAITING);
-        addStacktrace(stackMinus, timestamp);
+        instance.addStacktrace(stackMinus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackMinus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsMinus.length), instance.methodInfos.size()-1);
@@ -395,11 +394,11 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : minus/waiting; additional thread");
 
         setState(stack0[1], Thread.State.WAITING);
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackMinus[0], Thread.State.WAITING);
-        addStacktrace(stackMinus, timestamp);
+        instance.addStacktrace(stackMinus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackMinus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsMinus.length), instance.methodInfos.size()-1);
@@ -411,11 +410,11 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : waiting/minus");
 
         setState(stack0[0], Thread.State.WAITING);
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackMinus[0], Thread.State.RUNNABLE);
-        addStacktrace(stackMinus, timestamp);
+        instance.addStacktrace(stackMinus, timestamp);
 
         assertEquals(Math.max(stack0.length, stackMinus.length), instance.threadIds.size());
         assertEquals(Math.max(elements0.length, elementsMinus.length), instance.methodInfos.size()-1);
@@ -426,11 +425,11 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceDif() {
         System.out.println("add stacktrace : diff");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
 
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         assertEquals(Math.max(stack0.length, stackDif.length), instance.threadIds.size());
         for(StackTraceElement element : elements0) {
@@ -450,12 +449,12 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceDifWaiting() {
         System.out.println("add stacktrace : diff/waiting");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackDif[0], Thread.State.WAITING);
         
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
 
@@ -477,18 +476,18 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceDifWaitingBlocked() {
         System.out.println("add stacktrace : diff/waiting/blocked");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackDif[0], Thread.State.WAITING);
 
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         setState(stack0[0], Thread.State.BLOCKED);
 
         timestamp += 500000;
 
-        addStacktrace(stack0, timestamp);
+        instance.addStacktrace(stack0, timestamp);
 
         assertEquals(Thread.State.BLOCKED, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
 
@@ -510,18 +509,18 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStacktraceDifBlockedWaiting() {
         System.out.println("add stacktrace : diff/blocked/waiting");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
         setState(stackDif[0], Thread.State.BLOCKED);
 
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         setState(stack0[0], Thread.State.WAITING);
 
         timestamp += 500000;
 
-        addStacktrace(stack0, timestamp);
+        instance.addStacktrace(stack0, timestamp);
 
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
 
@@ -544,12 +543,12 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : waiting/diff");
 
         setState(stack0[0], Thread.State.WAITING);
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
 
 
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         assertEquals(Math.max(stack0.length, stackDif.length), instance.threadIds.size());
         for(StackTraceElement element : elements0) {
@@ -570,12 +569,12 @@ public class StackTraceSnapshotBuilderTest {
         System.out.println("add stacktrace : waiting/diff/runnable");
 
         setState(stack0[0], Thread.State.WAITING);
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
 
         long timestamp = 500000;
 
         setState(stackDif[0], Thread.State.RUNNABLE);
-        addStacktrace(stackDif, timestamp);
+        instance.addStacktrace(stackDif, timestamp);
 
         assertEquals(Math.max(stack0.length, stackDif.length), instance.threadIds.size());
         for(StackTraceElement element : elements0) {
@@ -598,7 +597,7 @@ public class StackTraceSnapshotBuilderTest {
         setState(stack0[0], Thread.State.NEW);
 
         try {
-            addStacktrace(stack0, 500000);
+            instance.addStacktrace(stack0, 500000);
             assertFalse(instance.threadNames.contains(stack0[0].getThreadName()));
         } catch (IllegalStateException ex) {}
     }
@@ -610,9 +609,9 @@ public class StackTraceSnapshotBuilderTest {
         setState(stack0[0], Thread.State.TERMINATED);
 
         try {
-            addStacktrace(stack0, 0);
+            instance.addStacktrace(stack0, 0);
             setState(stack0[0], Thread.State.RUNNABLE);
-            addStacktrace(stack0, 500000);
+            instance.addStacktrace(stack0, 500000);
             fail();
         } catch (IllegalStateException ex) {}
     }
@@ -624,7 +623,7 @@ public class StackTraceSnapshotBuilderTest {
 
         setState(stack0[0], Thread.State.RUNNABLE);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.RUNNABLE, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -636,7 +635,7 @@ public class StackTraceSnapshotBuilderTest {
 
         setState(stack0[0], Thread.State.WAITING);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -648,7 +647,7 @@ public class StackTraceSnapshotBuilderTest {
 
         setState(stack0[0], Thread.State.TIMED_WAITING);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.TIMED_WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -660,7 +659,7 @@ public class StackTraceSnapshotBuilderTest {
 
         setState(stack0[0], Thread.State.BLOCKED);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.BLOCKED, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -672,7 +671,7 @@ public class StackTraceSnapshotBuilderTest {
 
         setState(stack0[0], Thread.State.TERMINATED);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.TERMINATED, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -682,16 +681,16 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStackTraceWaitRun() {
         System.out.println("add stacktrace : wait->run");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         setState(stack0[0], Thread.State.WAITING);
         
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
 
         setState(stack0[0], Thread.State.RUNNABLE);
-        addStacktrace(stack0, 1000000);
+        instance.addStacktrace(stack0, 1000000);
 
         assertEquals(1000000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.RUNNABLE, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -701,14 +700,14 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStackTraceWaitWait() {
         System.out.println("add stacktrace : wait->wait");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         setState(stack0[0], Thread.State.WAITING);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
-        addStacktrace(stack0, 1000000);
+        instance.addStacktrace(stack0, 1000000);
 
         assertEquals(1000000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -718,15 +717,15 @@ public class StackTraceSnapshotBuilderTest {
     public void testAddStackTraceWaitBlocked() {
         System.out.println("add stacktrace : wait->blocked");
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         setState(stack0[0], Thread.State.WAITING);
 
-        addStacktrace(stack0, 500000);
+        instance.addStacktrace(stack0, 500000);
 
         assertEquals(500000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.WAITING, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
         setState(stack0[0], Thread.State.BLOCKED);
-        addStacktrace(stack0, 1000000);
+        instance.addStacktrace(stack0, 1000000);
 
         assertEquals(1000000, instance.currentDumpTimeStamp);
         assertEquals(Thread.State.BLOCKED, instance.lastStackTrace.get().get(thread0.getId()).getThreadState());
@@ -738,8 +737,8 @@ public class StackTraceSnapshotBuilderTest {
     public void testReset() {
         System.out.println("reset");
         ThreadMXBean tbean = ManagementFactory.getThreadMXBean();
-        addStacktrace(tbean.getThreadInfo(tbean.getAllThreadIds(), Integer.MAX_VALUE), System.nanoTime());
-        addStacktrace(tbean.getThreadInfo(tbean.getAllThreadIds(), Integer.MAX_VALUE), System.nanoTime());
+        instance.addStacktrace(tbean.getThreadInfo(tbean.getAllThreadIds(), Integer.MAX_VALUE), System.nanoTime());
+        instance.addStacktrace(tbean.getThreadInfo(tbean.getAllThreadIds(), Integer.MAX_VALUE), System.nanoTime());
 
         instance.reset();
         assertTrue(instance.methodInfos.size()-1 == 0);
@@ -763,7 +762,7 @@ public class StackTraceSnapshotBuilderTest {
         String ignoredThread = "Thread 0";
         instance.setIgnoredThreads(Collections.singleton(ignoredThread));
 
-        addStacktrace(stack0, 0);
+        instance.addStacktrace(stack0, 0);
         assertFalse(instance.threadNames.contains(ignoredThread));
     }
 
@@ -803,15 +802,4 @@ public class StackTraceSnapshotBuilderTest {
             Logger.getLogger(StackTraceSnapshotBuilderTest.class.getName()).log(Level.SEVERE, null, ex);
         }
     }
-
-    private void addStacktrace(java.lang.management.ThreadInfo[] tinfos, long time) {
-        java.lang.management.ThreadInfo[] newInfo = new java.lang.management.ThreadInfo[tinfos.length];
-        int i = 0;
-
-        for (java.lang.management.ThreadInfo tinfo : tinfos) {
-            CompositeData aaa = ThreadInfoCompositeData.toCompositeData(tinfo);
-            newInfo[i++] = ThreadInfo.from(aaa);
-        }
-        instance.addStacktrace(newInfo, time);
-    }
 }
