@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -47,7 +47,8 @@ public class TargetPlatformEnum {
                                                  IntegrationUtils.PLATFORM_JAVA_150,IntegrationUtils.PLATFORM_JAVA_160,
                                                  IntegrationUtils.PLATFORM_JAVA_170,IntegrationUtils.PLATFORM_JAVA_180,
                                                  IntegrationUtils.PLATFORM_JAVA_190,IntegrationUtils.PLATFORM_JAVA_200,
-                                                 IntegrationUtils.PLATFORM_JAVA_CVM,
+                                                 IntegrationUtils.PLATFORM_JAVA_210,IntegrationUtils.PLATFORM_JAVA_220,
+                                                 IntegrationUtils.PLATFORM_JAVA_230,IntegrationUtils.PLATFORM_JAVA_CVM,
                                              };
     public static final TargetPlatformEnum JDK5 = new TargetPlatformEnum(0);
     public static final TargetPlatformEnum JDK6 = new TargetPlatformEnum(1);
@@ -65,7 +66,10 @@ public class TargetPlatformEnum {
     public static final TargetPlatformEnum JDK18 = new TargetPlatformEnum(13);
     public static final TargetPlatformEnum JDK19 = new TargetPlatformEnum(14);
     public static final TargetPlatformEnum JDK20 = new TargetPlatformEnum(15);
-    public static final TargetPlatformEnum JDK_CVM = new TargetPlatformEnum(16);
+    public static final TargetPlatformEnum JDK21 = new TargetPlatformEnum(16);
+    public static final TargetPlatformEnum JDK22 = new TargetPlatformEnum(17);
+    public static final TargetPlatformEnum JDK23 = new TargetPlatformEnum(18);
+    public static final TargetPlatformEnum JDK_CVM = new TargetPlatformEnum(19);
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -93,7 +97,7 @@ public class TargetPlatformEnum {
     }
 
     public static Iterator<TargetPlatformEnum> iterator() {
-        List<TargetPlatformEnum> jvmList = new ArrayList<>(17);
+        List<TargetPlatformEnum> jvmList = new ArrayList<>(20);
         jvmList.add(JDK5);
         jvmList.add(JDK6);
         jvmList.add(JDK7);
@@ -110,6 +114,9 @@ public class TargetPlatformEnum {
         jvmList.add(JDK18);
         jvmList.add(JDK19);
         jvmList.add(JDK20);
+        jvmList.add(JDK21);
+        jvmList.add(JDK22);
+        jvmList.add(JDK23);
         jvmList.add(JDK_CVM);
 
         return jvmList.listIterator();
