@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,6 +24,7 @@
  */
 package org.graalvm.visualvm.lib.profiler.heapwalk.details.jdk;
 
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
@@ -80,6 +81,10 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
     private static final String DEQUE_MASK = "java.util.ArrayDeque+";           // NOI18N
     private static final String ENUM_SET_MASK = "java.util.RegularEnumSet";     // NOI18N
     private static final String CONCURRENT_MAP_MASK = "java.util.concurrent.ConcurrentHashMap";     // NOI18N
+    private static final String SET12_MASK = "java.util.ImmutableCollections$Set12"; //NOI18N
+    private static final String LIST12_MASK = "java.util.ImmutableCollections$List12"; //NOI18N
+    private static final String LISTN_MASK = "java.util.ImmutableCollections$ListN"; // NOI18N
+    private static final String MAP1_MASK = "java.util.ImmutableCollections$Map1"; // NOI18N
     
     private Formatter formatter = new SimpleFormatter();
 
@@ -92,7 +97,8 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
               EMPTY_LIST_MASK, EMPTY_MAP_MASK, EMPTY_SET_MASK,
               SINGLETON_LIST_MASK, SINGLETON_MAP_MASK, SINGLETON_SET_MASK,
               SYN_COLLECTION_MASK, SYN_MAP_MASK, DEQUE_MASK, ENUM_SET_MASK,
-              CONCURRENT_MAP_MASK);
+              CONCURRENT_MAP_MASK, SET12_MASK, LIST12_MASK, LISTN_MASK,
+              MAP1_MASK);
     }
     
     public String getDetailsString(String className, Instance instance) {
@@ -142,13 +148,15 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 int size = DetailsUtils.getIntFieldValue(instance, "size", -1);  // NOI18N
                 if (size != -1) {
                     return getElementsString(size);
-                }       break;
+                }
+                break;
             }
             case VECTOR_MASK: {
                 int elements = DetailsUtils.getIntFieldValue(instance, "elementCount", -1); // NOI18N
                 if (elements != -1) {
                     return getElementsString(elements);
-                }       break;
+                }
+                break;
             }
             case SET_MASK:
                 return DetailsUtils.getInstanceFieldString(instance, "map"); // NOI18N
@@ -160,7 +168,8 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 int elements = DetailsUtils.getIntFieldValue(instance, "count", -1);     // NOI18N
                 if (elements != -1) {
                     return getElementsString(elements);
-                }       break;
+                }
+                break;
             }
             case PROP_MASK:
                 return DetailsUtils.getInstanceFieldString(instance, "map");    // NOI18N
@@ -180,7 +189,8 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 ObjectArrayInstance arr = (ObjectArrayInstance) instance.getValueOfField("a");  // NOI18N
                 if (arr != null) {
                     return getElementsString(arr.getLength());
-                }       break;
+                }
+                break;
             }
             case EMPTY_LIST_MASK:
             case EMPTY_MAP_MASK:
@@ -197,7 +207,8 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 if (head != -1 && tail != -1 && arr != null) {
                     int size = (tail - head) & (arr.getLength() - 1);
                     return getElementsString(size);
-                }       break;
+                }
+                break;
             }
             case SYN_COLLECTION_MASK:
                 return DetailsUtils.getInstanceFieldString(instance, "c");    // NOI18N
@@ -207,7 +218,8 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 Object elements = instance.getValueOfField("elements");             // NOI18N
                 if (elements instanceof Long) {
                     return getElementsString(Long.bitCount((Long)elements));
-                }       break;
+                }
+                break;
             }
             case CONCURRENT_MAP_MASK: {
                 long baseCount = DetailsUtils.getLongFieldValue(instance, "baseCount", -1);     // NOI18N
@@ -217,6 +229,21 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
                 }
                 break;
             }
+            case SET12_MASK:
+            case LIST12_MASK: {
+                Object e1 = instance.getValueOfField("e1");     // NOI18N
+                return getElementsString(e1 != null ? 2 : 1);
+            }
+            case LISTN_MASK: {
+                Object elements = instance.getValueOfField("elements"); // NOI18N
+                if (elements instanceof ObjectArrayInstance) {
+                    return getElementsString(((ObjectArrayInstance)elements).getLength());
+                }
+                break;
+            }
+            case MAP1_MASK: {
+                return getElementsString(1);
+            }
             default:
                 break;
         }
@@ -265,11 +292,7 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
 
         @Override
         public long getMillis() {
-            Object time = record.getValueOfField("millis");
-            if (time instanceof Number) {
-                return ((Number)time).longValue();
-            }
-            return 0;
+            return getInstant().toEpochMilli();
         }
 
         @Override
@@ -292,6 +315,19 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
             return DetailsUtils.getInstanceFieldString(record, "message");    // NOI18N
         }
 
+        // @Override since JDK 9
+        public Instant getInstant() {
+            Object instant = record.getValueOfField("instant");     // NOI18N
+            if (instant instanceof Instance) {
+                return TimeDetailsProvider.getInstant(instant);
+            }
+            Object time = record.getValueOfField("millis");
+            if (time instanceof Number) {
+                return Instant.ofEpochMilli(((Number)time).longValue());
+            }
+            return Instant.EPOCH;
+        }
+
         @Override
         public Object[] getParameters() {
             Object pars = record.getValueOfField("parameters");
@@ -314,7 +350,21 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
         @Override
         public Level getLevel() {
             String level = DetailsUtils.getInstanceFieldString(record, "level");  // NOI18N
-            return Level.parse(level);
+            try {
+                return Level.parse(level);
+            } catch (RuntimeException ex) {
+                // custom level, construct level directly
+                Instance levelObj = (Instance)record.getValueOfField("level");  // NOI18N
+                Integer value = (Integer)levelObj.getValueOfField("value");     // NOI18N
+                if (level == null) level = "NULL";        // NOI18N
+                return new CustomLevel(level, value);     // NOI18N
+            }
+        }
+    }
+
+    private static class CustomLevel extends Level {
+        private CustomLevel(String name, int value) {
+            super(name, value);
         }
     }
 }
