@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.profiler.actions;
@@ -129,7 +111,7 @@ public class CompareSnapshotsAction extends AbstractAction {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public SelectExternalSnapshotsPanel() {
+        SelectExternalSnapshotsPanel() {
             initComponents();
         }
 
@@ -281,7 +263,7 @@ public class CompareSnapshotsAction extends AbstractAction {
             snapshot2Button.addActionListener(new ActionListener() {
                     public void actionPerformed(ActionEvent e) {
                         JFileChooser snapshotChooser = CompareSnapshotsAction.getSnapshotFileChooser();
-                        snapshotChooser.setCurrentDirectory(new File((getSnapshot2Filename().length() == 0)
+                        snapshotChooser.setCurrentDirectory(new File(getSnapshot2Filename().isEmpty()
                                                                      ? getSnapshot1Filename() : getSnapshot2Filename()));
 
                         if (snapshotChooser.showOpenDialog(WindowManager.getDefault().getMainWindow()) == 0) {
@@ -301,7 +283,7 @@ public class CompareSnapshotsAction extends AbstractAction {
             String s1f = getSnapshot1Filename();
             String s2f = getSnapshot2Filename();
 
-            if ((s1f.length() > 0) && (s2f.length() > 0)) {
+            if (!s1f.isEmpty() && !s2f.isEmpty()) {
                 // filenames not empty string
                 final File s1 = new File(s1f);
                 final File s2 = new File(s2f);
@@ -395,7 +377,7 @@ public class CompareSnapshotsAction extends AbstractAction {
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public SelectSecondSnapshotPanel() {
+        SelectSecondSnapshotPanel() {
             initComponents();
         }
 
@@ -422,7 +404,7 @@ public class CompareSnapshotsAction extends AbstractAction {
             } else if (fromFileRadio.isSelected()) {
                 String sf = externalFileField.getText();
 
-                if (sf.length() > 0) {
+                if (!sf.isEmpty()) {
                     File s = new File(sf);
 
                     if (s.exists() && s.isFile()) {
@@ -447,10 +429,9 @@ public class CompareSnapshotsAction extends AbstractAction {
             // TODO: check that this works correctly in VisualVM!
             LoadedSnapshot[] loadedSnapshots = ResultsManager.getDefault().getLoadedSnapshots();
 
-            for (int i = 0; i < loadedSnapshots.length; i++) {
-                if ((loadedSnapshots[i] != snapshot) && (loadedSnapshots[i].getFile() == null)
-                        && areComparableSnapshots(snapshot, loadedSnapshots[i])) {
-                    listModel.addElement(loadedSnapshots[i]);
+            for (LoadedSnapshot loadedSnapshot : loadedSnapshots) {
+                if ((loadedSnapshot != snapshot) && (loadedSnapshot.getFile() == null) && areComparableSnapshots(snapshot, loadedSnapshot)) {
+                    listModel.addElement(loadedSnapshot);
                 }
             }
 
@@ -461,10 +442,9 @@ public class CompareSnapshotsAction extends AbstractAction {
             FileObject[] snapshotsOnDisk = ResultsManager.getDefault().listSavedSnapshots(project, snapshotDir);
             FileObject snapshotFile = (snapFile != null) ? FileUtil.toFileObject(snapFile) : null;
             
-            for (int i = 0; i < snapshotsOnDisk.length; i++) {
-                if (((snapshotFile == null) || !snapshotsOnDisk[i].equals(snapshotFile))
-                        && areComparableSnapshots(snapshot, snapshotsOnDisk[i])) {
-                    listModel.addElement(snapshotsOnDisk[i]);
+            for (FileObject snapshotsOnDisk1 : snapshotsOnDisk) {
+                if (((snapshotFile == null) || !snapshotsOnDisk1.equals(snapshotFile)) && areComparableSnapshots(snapshot, snapshotsOnDisk1)) {
+                    listModel.addElement(snapshotsOnDisk1);
                 }
             }
 
@@ -791,7 +771,7 @@ public class CompareSnapshotsAction extends AbstractAction {
                 // Snapshot from file
                 String sf = externalFileField.getText();
 
-                if (sf.length() > 0) {
+                if (!sf.isEmpty()) {
                     // filename not empty string
                     File s = new File(sf);
 
