@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -25,30 +25,6 @@
 
 package org.graalvm.visualvm.sampler.truffle;
 
-import org.graalvm.visualvm.sampler.truffle.cpu.ThreadInfoProvider;
-import org.graalvm.visualvm.sampler.truffle.memory.MemorySettingsSupport;
-import org.graalvm.visualvm.sampler.truffle.cpu.CPUSettingsSupport;
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.core.datasource.DataSource;
-import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
-import org.graalvm.visualvm.core.datasupport.Utils;
-import org.graalvm.visualvm.core.ui.DataSourceWindowManager;
-import org.graalvm.visualvm.core.ui.components.DataViewComponent;
-import org.graalvm.visualvm.core.ui.components.ScrollableContainer;
-import org.graalvm.visualvm.core.ui.components.Spacer;
-import org.graalvm.visualvm.heapdump.HeapDumpSupport;
-import org.graalvm.visualvm.profiling.presets.PresetSelector;
-import org.graalvm.visualvm.profiling.presets.ProfilerPresets;
-import org.graalvm.visualvm.profiling.snapshot.ProfilerSnapshot;
-import org.graalvm.visualvm.sampler.truffle.cpu.CPUSamplerSupport;
-import org.graalvm.visualvm.sampler.truffle.memory.MemorySamplerSupport;
-import org.graalvm.visualvm.threaddump.ThreadDumpSupport;
-import org.graalvm.visualvm.tools.jmx.JmxModel;
-import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
-import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
-import org.graalvm.visualvm.uisupport.HTMLLabel;
-import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import java.awt.Dimension;
 import java.awt.Font;
 import java.awt.GridBagConstraints;
@@ -79,7 +55,16 @@ import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JToggleButton;
 import javax.swing.SwingUtilities;
+import org.graalvm.visualvm.application.Application;
 import org.graalvm.visualvm.core.VisualVM;
+import org.graalvm.visualvm.core.datasource.DataSource;
+import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
+import org.graalvm.visualvm.core.datasupport.Utils;
+import org.graalvm.visualvm.core.ui.DataSourceWindowManager;
+import org.graalvm.visualvm.core.ui.components.DataViewComponent;
+import org.graalvm.visualvm.core.ui.components.ScrollableContainer;
+import org.graalvm.visualvm.core.ui.components.Spacer;
+import org.graalvm.visualvm.heapdump.HeapDumpSupport;
 import org.graalvm.visualvm.lib.common.ProfilingSettings;
 import org.graalvm.visualvm.lib.common.ProfilingSettingsPresets;
 import org.graalvm.visualvm.lib.jfluid.results.cpu.CPUResultsSnapshot;
@@ -87,7 +72,23 @@ import org.graalvm.visualvm.lib.jfluid.results.memory.SampledMemoryResultsSnapsh
 import org.graalvm.visualvm.lib.profiler.LoadedSnapshot;
 import org.graalvm.visualvm.lib.profiler.ResultsManager;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
+import org.graalvm.visualvm.profiling.presets.PresetSelector;
+import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
+import org.graalvm.visualvm.profiling.presets.ProfilerPresets;
+import org.graalvm.visualvm.profiling.snapshot.ProfilerSnapshot;
+import org.graalvm.visualvm.sampler.truffle.cpu.CPUSamplerSupport;
+import org.graalvm.visualvm.sampler.truffle.cpu.CPUSettingsSupport;
+import org.graalvm.visualvm.sampler.truffle.cpu.ThreadInfoProvider;
 import org.graalvm.visualvm.sampler.truffle.memory.MemoryHistogramProvider;
+import org.graalvm.visualvm.sampler.truffle.memory.MemorySamplerSupport;
+import org.graalvm.visualvm.sampler.truffle.memory.MemorySettingsSupport;
+import org.graalvm.visualvm.threaddump.ThreadDumpSupport;
+import org.graalvm.visualvm.tools.jmx.JmxModel;
+import org.graalvm.visualvm.tools.jmx.JmxModelFactory;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeans;
+import org.graalvm.visualvm.tools.jmx.JvmMXBeansFactory;
+import org.graalvm.visualvm.uisupport.HTMLLabel;
+import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.ImageUtilities;
@@ -124,7 +125,7 @@ final class SamplerImpl {
     private AbstractSamplerSupport memorySampler;
     private MemorySettingsSupport memorySettings;
     
-    private DefaultComboBoxModel selectorModel;
+    private DefaultComboBoxModel<ProfilerPreset> selectorModel;
     private List<PresetSelector> allSelectors;
 
     private DataViewComponent dvc;
@@ -158,8 +159,8 @@ final class SamplerImpl {
     }
     
     private PresetSelector createSelector(Runnable presetSynchronizer) {
-        if (selectorModel == null) selectorModel = new DefaultComboBoxModel();
-        if (allSelectors == null) allSelectors = new ArrayList();
+        if (selectorModel == null) selectorModel = new DefaultComboBoxModel<>();
+        if (allSelectors == null) allSelectors = new ArrayList<>();
         PresetSelector selector = ProfilerPresets.getInstance().createSelector(
                                   application, selectorModel, allSelectors, presetSynchronizer);
         allSelectors.add(selector);
@@ -513,6 +514,7 @@ final class SamplerImpl {
             public void run() {
                 ThreadInfoProvider ti = new ThreadInfoProvider(application, mode, splitCompiledInlined);
                 final String status = ti.getStatus();
+                final boolean modeAvailable = ti.isModeVailable();
                 
                 if (status != null) {
                     SwingUtilities.invokeLater(new Runnable() {
@@ -578,9 +580,7 @@ final class SamplerImpl {
                         if (noThreadDump != null) {
                             String[] msgs = new String[2];
                             int i = 0;
-                            if (noThreadDump != null) {
-                                msgs[i++] = noThreadDump;
-                            }
+                            msgs[i++] = noThreadDump;
                             if (i == 1) {
                                 avail = NbBundle.getMessage(SamplerImpl.class,
                                         "MSG_Available_details", msgs[0]); // NOI18N
@@ -591,6 +591,7 @@ final class SamplerImpl {
                         }
                         cpuStatus = avail + " " + NbBundle.getMessage(SamplerImpl.class, "MSG_Press_cpu"); // NOI18N
                         cpuProfilingSupported = true;
+                        if (!modeAvailable) cpuSettings.enableMode(modeAvailable);
                         refreshSummary();
                         updateButtons();
                         updateSettings();
@@ -961,7 +962,7 @@ final class SamplerImpl {
 
     private static final class OneWayToggleButton extends JToggleButton {
 
-        public OneWayToggleButton(String text) {
+        OneWayToggleButton(String text) {
             super(text);
         }
 
