@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -98,9 +98,9 @@ final class ThreadsMemoryView extends JPanel {
         this.memoryBean = memoryBean;
         this.heapDumper = heapDumper;
         
-        threads = Collections.EMPTY_LIST;
-        allocatedBytes = Collections.EMPTY_LIST;
-        allocatedBytesPerSec = Collections.EMPTY_LIST;
+        threads = Collections.emptyList();
+        allocatedBytes = Collections.emptyList();
+        allocatedBytesPerSec = Collections.emptyList();
         
         initComponents();
         
@@ -434,7 +434,7 @@ final class ThreadsMemoryView extends JPanel {
         JComponent panel = getBottomPanel();
         
         if (filterPanel == null) {
-            filterPanel = FilterUtils.createFilterPanel(table, null);
+            filterPanel = FilterUtils.createFilterPanel(table);
             panel.add(filterPanel);
             Container parent = panel.getParent();
             parent.invalidate();
