@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2020, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,7 +86,11 @@ public class ImportSettings {
         "2.1.3",                                                                // NOI18N
         "2.1.4",                                                                // NOI18N
         "2.1.5",                                                                // NOI18N
-        "2.1.6"                                                                 // NOI18N
+        "2.1.6",                                                                // NOI18N
+        "2.1.7",                                                                // NOI18N
+        "2.1.8",                                                                // NOI18N
+        "2.1.9",                                                                // NOI18N
+        "2.1.10"                                                                // NOI18N
     };
     
     
@@ -244,13 +248,13 @@ public class ImportSettings {
     
     
     /* Copy files from source folder to current userdir according to include/exclude
-     * patterns in etc/netbeans.import file. */
+     * patterns in etc/visualvm.import file. */
     private static void copyToUserdir(File source, File userdir) throws IOException, PropertyVetoException {
-        File netBeansDir = InstalledFileLocator.getDefault().locate("modules", null, false).getParentFile().getParentFile(); // NOI18N
+        File visualvmDir = InstalledFileLocator.getDefault().locate("modules", null, false).getParentFile().getParentFile(); // NOI18N
         
-        File importFile = new File(netBeansDir, "etc/visualvm.import");         // NOI18N
+        File importFile = new File(visualvmDir, "etc/visualvm.import");         // NOI18N
 ///*DEV*/ if (!importFile.isFile() && "testuserdir".equals(userdir.getName())) {  // NOI18N
-///*DEV*/     File parent = netBeansDir.getParentFile();
+///*DEV*/     File parent = visualvmDir.getParentFile();
 ///*DEV*/     if (parent != null && parent.isDirectory()) {
 ///*DEV*/         importFile = new File(parent, "launcher/visualvm.import");      // NOI18N
 ///*DEV*/     }
