@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -148,6 +148,11 @@ public abstract class ProfilerTabbedView {
     public abstract void removeViewListener(Listener listener);
     
     
+    public void setShowsTabPopup(boolean showsTabPopup) {}
+    
+    public boolean getShowsTabPopup() { return true; }
+    
+    
     protected ProfilerTabbedView() {}
     
     
@@ -189,6 +194,7 @@ public abstract class ProfilerTabbedView {
         private boolean firstClosable;
         
         private ProfilerTabbedPane tabs;
+        private boolean showsTabPopup = true;
         
         private Component focusMaster;
         
@@ -244,6 +250,7 @@ public abstract class ProfilerTabbedView {
                 } else {
                     component.remove(firstView);
                     tabs = createTabs(tabPlacement, tabLayoutPolicy, minimizeOuterMargin);
+                    tabs.setShowsTabPopup(showsTabPopup);
                     tabs.addTab(firstName, firstIcon, createViewport(firstView), firstDescription, firstClosable);
                     tabs.addTab(name, icon, createViewport(view), description, closable);
                     component.add(tabs, BorderLayout.CENTER);
@@ -361,7 +368,7 @@ public abstract class ProfilerTabbedView {
         private Collection<JComponent> getAllViews() {
             if (tabs != null) {
                 int tabsCount = tabs.getTabCount();
-                List<JComponent> allViews = new ArrayList(tabsCount);
+                List<JComponent> allViews = new ArrayList<>(tabsCount);
                 for (int i = 0; i < tabsCount; i++)
                     allViews.add(((TabbedPaneViewport)tabs.getComponentAt(i)).getView());
                 return allViews;
@@ -433,7 +440,7 @@ public abstract class ProfilerTabbedView {
         
         
         public void addViewListener(Listener listener) {
-            if (viewListeners == null) viewListeners = new ArrayList(3);
+            if (viewListeners == null) viewListeners = new ArrayList<>(3);
             viewListeners.add(listener);
         }
     
@@ -444,17 +451,29 @@ public abstract class ProfilerTabbedView {
         }
         
         protected final void fireViewAdded(JComponent view) {
-            for (Listener viewListener : viewListeners)
-                viewListener.viewAdded(view);
+            if (viewListeners != null)
+                for (Listener viewListener : viewListeners)
+                    viewListener.viewAdded(view);
         }
         
         protected final void fireViewRemoved(JComponent view) {
-            for (Listener viewListener : viewListeners)
-                viewListener.viewRemoved(view);
+            if (viewListeners != null)
+                for (Listener viewListener : viewListeners)
+                    viewListener.viewRemoved(view);
         }
         
         
-        protected final TabbedPaneViewport createViewport(JComponent view) {
+        public void setShowsTabPopup(boolean showsTabPopup) {
+            this.showsTabPopup = showsTabPopup;
+            if (tabs != null) tabs.setShowsTabPopup(showsTabPopup);
+        }
+    
+        public boolean getShowsTabPopup() {
+            return showsTabPopup;
+        }
+        
+        
+        private final TabbedPaneViewport createViewport(JComponent view) {
             return new TabbedPaneViewport(view) {
                 Component getFocusMaster() { return focusMaster; }
                 int getTabPlacement() { return tabPlacement; }
@@ -511,7 +530,7 @@ public abstract class ProfilerTabbedView {
         
         private static final int HIGHLIGHTS_COUNT = 2;
         private static final int HIGHLIGHTS_DURATION = 300;
-        private final Map<TabbedPaneViewport, Integer> highlights = new HashMap();
+        private final Map<TabbedPaneViewport, Integer> highlights = new HashMap<>();
         
         private void highlightTab(TabbedPaneViewport viewport) {
             Integer icount = highlights.get(viewport);
@@ -536,7 +555,7 @@ public abstract class ProfilerTabbedView {
             }
             
             int idx = tabs.indexOfComponent(viewport);
-            if (idx == -1) { highlights.remove(viewport); return; };
+            if (idx == -1) { highlights.remove(viewport); return; }
             
             final Color originalForeground = tabs.getForegroundAt(idx);
             Color highlightForeground = Color.BLUE;
@@ -626,7 +645,7 @@ public abstract class ProfilerTabbedView {
                         Component cc = c;
                         while (c != null) {
                             if (c == getFocusMaster()) {
-                                lastFocusOwner = new WeakReference(cc);
+                                lastFocusOwner = new WeakReference<>(cc);
                                 return;
                             }
                             c = c.getParent();
